@@ -24,10 +24,13 @@ from click_plugins import with_plugins
 from pkg_resources import iter_entry_points
 from tqdm import tqdm
 
-from .canonicalize import to_bel
+from .canonicalize import to_bel_script
 from .constants import get_cache_connection
 from .examples import braf_graph, egf_graph, homology_graph, sialic_acid_graph, statin_graph
-from .io import from_path, from_pickle, to_csv, to_graphml, to_gsea, to_json_file, to_neo4j, to_pickle, to_sif, to_web
+from .io import (
+    from_bel_script, from_pickle, to_edgelist, to_graphml, to_gsea, to_neo4j, to_nodelink_file, to_pickle, to_sif,
+    to_tsv, to_web,
+)
 from .io.web import _get_host
 from .manager import Manager
 from .manager.database_io import to_database
@@ -37,7 +40,7 @@ from .struct import get_unused_annotations, get_unused_list_annotation_values, g
 from .struct.graph import BELGraph, WarningTuple
 from .utils import get_corresponding_pickle_path
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 
 def _page(it):
@@ -64,8 +67,10 @@ def _from_pickle_callback(ctx, param, file):
     cache_path = get_corresponding_pickle_path(path)
 
     if not os.path.exists(cache_path):
-        click.echo('The BEL script {path} has not yet been compiled. First, try running the following command:\n\n '
-                   'pybel compile {path}\n'.format(path=path))
+        click.echo(
+            'The BEL script {path} has not yet been compiled. First, try running the following command:\n\n '
+            'pybel compile {path}\n'.format(path=path),
+        )
         sys.exit(1)
 
     return from_pickle(cache_path)
@@ -93,36 +98,41 @@ def main(ctx, connection):
 @main.command()
 @click.argument('path')
 @click.option('--allow-naked-names', is_flag=True, help="Enable lenient parsing for naked names")
-@click.option('--allow-nested', is_flag=True, help="Enable lenient parsing for nested statements")
+@click.option('--disallow-nested', is_flag=True, help="Disable lenient parsing for nested statements")
 @click.option('--disallow-unqualified-translocations', is_flag=True, help="Disallow unqualified translocations")
 @click.option('--no-identifier-validation', is_flag=True, help='Turn off identifier validation')
 @click.option('--no-citation-clearing', is_flag=True, help='Turn off citation clearing')
 @click.option('-r', '--required-annotations', multiple=True, help='Specify multiple required annotations')
+@click.option('--upgrade-urls', is_flag=True)
 @click.option('--skip-tqdm', is_flag=True)
 @click.option('-v', '--verbose', is_flag=True)
 @click.pass_obj
-def compile(manager, path, allow_naked_names, allow_nested, disallow_unqualified_translocations,
-            no_identifier_validation, no_citation_clearing, required_annotations, skip_tqdm, verbose):
+def compile(
+    manager, path, allow_naked_names, disallow_nested, disallow_unqualified_translocations,
+    no_identifier_validation, no_citation_clearing, required_annotations, upgrade_urls,
+    skip_tqdm, verbose,
+):
     """Compile a BEL script to a graph."""
     if verbose:
         logging.basicConfig(level=logging.DEBUG)
-        log.setLevel(logging.DEBUG)
-        log.debug('using connection: %s', manager.engine.url)
+        logger.setLevel(logging.DEBUG)
+        logger.debug('using connection: %s', manager.engine.url)
 
     click.secho('Compilation', fg='red', bold=True)
     if skip_tqdm:
         click.echo('```')
-    graph = from_path(
+    graph = from_bel_script(
         path,
         manager=manager,
         use_tqdm=(not (skip_tqdm or verbose)),
-        allow_nested=allow_nested,
+        disallow_nested=disallow_nested,
         allow_naked_names=allow_naked_names,
         disallow_unqualified_translocations=disallow_unqualified_translocations,
         citation_clearing=(not no_citation_clearing),
         required_annotations=required_annotations,
         no_identifier_validation=no_identifier_validation,
         allow_definition_failures=True,
+        upgrade_urls=upgrade_urls,
     )
     if skip_tqdm:
         click.echo('```')
@@ -151,7 +161,7 @@ def _print_summary(graph: BELGraph, ticks: bool = False):
         click.secho(
             '\nUnused Namespaces ({}/{})'.format(len(unused_namespaces), len(graph.defined_namespace_keywords)),
             fg='red',
-            bold=True
+            bold=True,
         )
         if ticks:
             click.echo('```')
@@ -165,7 +175,7 @@ def _print_summary(graph: BELGraph, ticks: bool = False):
         click.secho(
             '\nUnused Annotations ({}/{})'.format(len(unused_annotations), len(graph.defined_annotation_keywords)),
             fg='red',
-            bold=True
+            bold=True,
         )
         if ticks:
             click.echo('```')
@@ -213,37 +223,42 @@ def post(graph: BELGraph, host: str):
 
 @main.command()
 @graph_pickle_argument
-@click.option('--csv', type=click.File('w'), help='Path to output a CSV file.')
+@click.option('--tsv', type=click.File('w'), help='Path to output a TSV file.')
+@click.option('--edgelist', type=click.File('w'), help='Path to output a edgelist file.')
 @click.option('--sif', type=click.File('w'), help='Path to output an SIF file.')
 @click.option('--gsea', type=click.File('w'), help='Path to output a GRP file for gene set enrichment analysis.')
 @click.option('--graphml', help='Path to output a GraphML file. Use .graphml for Cytoscape.')
-@click.option('--json', type=click.File('w'), help='Path to output a node-link JSON file.')
+@click.option('--nodelink', type=click.File('w'), help='Path to output a node-link JSON file.')
 @click.option('--bel', type=click.File('w'), help='Output canonical BEL.')
-def serialize(graph: BELGraph, csv, sif, gsea, graphml, json, bel):
+def serialize(graph: BELGraph, tsv, edgelist, sif, gsea, graphml, nodelink, bel):
     """Serialize a graph to various formats."""
-    if csv:
-        log.info('Outputting CSV to %s', csv)
-        to_csv(graph, csv)
+    if tsv:
+        logger.info('Outputting TSV to %s', tsv)
+        to_tsv(graph, tsv)
+
+    if edgelist:
+        logger.info('Outputting edgelist to %s', edgelist)
+        to_edgelist(graph, edgelist)
 
     if sif:
-        log.info('Outputting SIF to %s', sif)
+        logger.info('Outputting SIF to %s', sif)
         to_sif(graph, sif)
 
     if graphml:
-        log.info('Outputting GraphML to %s', graphml)
+        logger.info('Outputting GraphML to %s', graphml)
         to_graphml(graph, graphml)
 
     if gsea:
-        log.info('Outputting GRP to %s', gsea)
+        logger.info('Outputting GRP to %s', gsea)
         to_gsea(graph, gsea)
 
-    if json:
-        log.info('Outputting JSON to %s', json)
-        to_json_file(graph, json)
+    if nodelink:
+        logger.info('Outputting Nodelink JSON to %s', nodelink)
+        to_nodelink_file(graph, nodelink)
 
     if bel:
-        log.info('Outputting BEL to %s', bel)
-        to_bel(graph, bel)
+        logger.info('Outputting BEL script to %s', bel)
+        to_bel_script(graph, bel)
 
 
 @main.command()
@@ -302,9 +317,14 @@ def drop(manager: Manager):
 
 
 @manage.command()
+@click.option('-v', '--debug', is_flag=True)
 @click.pass_obj
-def examples(manager: Manager):
+def examples(manager: Manager, debug: bool):
     """Load examples to the database."""
+    level = logging.DEBUG if debug else logging.INFO
+    logging.basicConfig(level=level)
+    logging.getLogger('pybel').setLevel(level)
+
     for graph in (sialic_acid_graph, statin_graph, homology_graph, braf_graph, egf_graph):
         if manager.has_name_version(graph.name, graph.version):
             click.echo('already inserted {}'.format(graph))
@@ -344,14 +364,16 @@ def ls(manager: Manager, url: Optional[str], namespace_id: Optional[int]):
     """List cached namespaces."""
     if url:
         n = manager.get_or_create_namespace(url)
-        if isinstance(n, Namespace):
-            _page(n.entries)
-        else:
-            click.echo('uncachable namespace')
+        _page(n.entries)
     elif namespace_id is not None:
         _ls(manager, Namespace, namespace_id)
     else:
-        click.echo('Missing argument -i or -u')
+        click.echo_via_pager(
+            '\n'.join(
+                "{}\t{}\t{}".format(n.id, n.name, n.url)
+                for n in manager.session.query(Namespace)
+            ),
+        )
 
 
 @namespaces.command()  # noqa:F811
@@ -465,16 +487,20 @@ def echo_warnings_via_pager(warnings: List[WarningTuple], sep: str = '\t') -> No
     def _make_line(path: str, exc: BELParserWarning):
         s = click.style(path, fg='cyan') + sep
         s += click.style(s1.format(exc.line_number), fg='blue', bold=True)
-        s += click.style(s2.format(exc.__class__.__name__),
-                         fg=('red' if exc.__class__.__name__.endswith('Error') else 'yellow'))
+        s += click.style(
+            s2.format(exc.__class__.__name__),
+            fg=('red' if exc.__class__.__name__.endswith('Error') else 'yellow'),
+        )
         s += click.style(exc.line, bold=True) + sep
         s += click.style(str(exc))
         return s
 
-    click.echo_via_pager('\n'.join(
-        _make_line(path, exc)
-        for path, exc, _ in warnings
-    ))
+    click.echo_via_pager(
+        '\n'.join(
+            _make_line(path, exc)
+            for path, exc, _ in warnings
+        ),
+    )
 
 
 if __name__ == '__main__':
