@@ -7,27 +7,40 @@ JSON. Interchange with this format provides compatibilty with other software and
 `Causal Biological Network Database <http://causalbionet.com/>`_.
 """
 
+import gzip
+import json
 import logging
 from collections import defaultdict
 from operator import methodcaller
+from typing import TextIO, Union
 
+import requests
+from networkx.utils import open_file
 from pyparsing import ParseException
 
 from ..constants import (
-    ANNOTATIONS, CITATION, CITATION_REFERENCE, CITATION_TYPE, EVIDENCE, FUNCTION, METADATA_AUTHORS, METADATA_CONTACT,
+    ANNOTATIONS, CITATION, EVIDENCE, METADATA_AUTHORS, METADATA_CONTACT,
     METADATA_INSERT_KEYS, METADATA_LICENSES, RELATION, UNQUALIFIED_EDGES,
 )
 from ..parser import BELParser
 from ..parser.exc import NakedNameWarning
 from ..struct import BELGraph
+from ..version import get_version
 
 __all__ = [
     'from_cbn_jgif',
     'from_jgif',
+    'from_jgif_file',
+    'from_jgif_gz',
+    'from_jgif_jsons',
     'to_jgif',
+    'to_jgif_file',
+    'to_jgif_gz',
+    'to_jgif_jsons',
+    'post_jgif',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 annotation_map = {
     'tissue': 'Tissue',
@@ -47,18 +60,6 @@ placeholder_evidence = "This Network edge has no supporting evidence.  Please ad
 EXPERIMENT_CONTEXT = 'experiment_context'
 
 
-def reformat_citation(citation):
-    """Reformat a citation dictionary.
-
-    :type citation: dict[str,str]
-    :rtype: dict[str,str]
-    """
-    return {
-        CITATION_TYPE: citation['type'].strip(),
-        CITATION_REFERENCE: citation['id'].strip()
-    }
-
-
 def map_cbn(d):
     """Pre-processes the JSON from the CBN.
 
@@ -69,13 +70,13 @@ def map_cbn(d):
     :rtype: dict
     """
     for i, edge in enumerate(d['graph']['edges']):
-        if 'metadata' not in d['graph']['edges'][i]:
+        if 'metadata' not in edge:
             continue
 
-        if 'evidences' not in d['graph']['edges'][i]['metadata']:
+        if 'evidences' not in edge['metadata']:
             continue
 
-        for j, evidence in enumerate(d['graph']['edges'][i]['metadata']['evidences']):
+        for j, evidence in enumerate(edge['metadata']['evidences']):
             if EXPERIMENT_CONTEXT not in evidence:
                 continue
 
@@ -85,13 +86,13 @@ def map_cbn(d):
 
             for key, value in evidence[EXPERIMENT_CONTEXT].items():
                 if not value:
-                    log.debug('key %s without value', key)
+                    logger.debug('key %s without value', key)
                     continue
 
                 value = value.strip()
 
                 if not value:
-                    log.debug('key %s without value', key)
+                    logger.debug('key %s without value', key)
                     continue
 
                 key = key.strip().lower()
@@ -119,6 +120,7 @@ def map_cbn(d):
                     'species_common_name']
             '''
 
+            # TODO can this be replaced with edge as well?
             d['graph']['edges'][i]['metadata']['evidences'][j][EXPERIMENT_CONTEXT] = new_context
 
     return d
@@ -134,7 +136,6 @@ def from_cbn_jgif(graph_jgif_dict):
     :rtype: BELGraph
 
     Example:
-
     >>> import requests
     >>> from pybel import from_cbn_jgif
     >>> apoptosis_url = 'http://causalbionet.com/Networks/GetJSONGraphFile?networkId=810385422'
@@ -146,6 +147,7 @@ def from_cbn_jgif(graph_jgif_dict):
         Handling the annotations is not yet supported, since the CBN documents do not refer to the resources used
         to create them. This may be added in the future, but the annotations must be stripped from the graph
         before uploading to the network store using :func:`pybel.struct.mutation.strip_annotations`.
+
     """
     graph_jgif_dict = map_cbn(graph_jgif_dict)
 
@@ -227,32 +229,32 @@ def from_jgif(graph_jgif_dict):
         node_label = node.get('label')
 
         if node_label is None:
-            log.warning('node missing label: %s', node)
+            logger.warning('node missing label: %s', node)
             continue
 
         try:
             parser.bel_term.parseString(node_label)
         except NakedNameWarning as e:
-            log.info('Naked name: %s', e)
+            logger.info('Naked name: %s', e)
         except ParseException:
-            log.info('Parse exception for %s', node_label)
+            logger.info('Parse exception for %s', node_label)
 
     for i, edge in enumerate(root['edges']):
         relation = edge.get('relation')
         if relation is None:
-            log.warning('no relation for edge: %s', edge)
+            logger.warning('no relation for edge: %s', edge)
 
         if relation in {'actsIn', 'translocates'}:
             continue  # don't need legacy BEL format
 
         edge_metadata = edge.get('metadata')
         if edge_metadata is None:
-            log.warning('no metadata for edge: %s', edge)
+            logger.warning('no metadata for edge: %s', edge)
             continue
 
         bel_statement = edge.get('label')
         if bel_statement is None:
-            log.debug('No BEL statement for edge %s', edge)
+            logger.debug('No BEL statement for edge %s', edge)
 
         evidences = edge_metadata.get('evidences')
 
@@ -261,7 +263,7 @@ def from_jgif(graph_jgif_dict):
 
         else:
             if not evidences:  # is none or is empty list
-                log.debug('No evidence for edge %s', edge)
+                logger.debug('No evidence for edge %s', edge)
                 continue
 
             for evidence in evidences:
@@ -279,18 +281,39 @@ def from_jgif(graph_jgif_dict):
                     continue
 
                 parser.control_parser.clear()
-                parser.control_parser.citation = reformat_citation(citation)
+                parser.control_parser.citation_db = citation['type'].strip()
+                parser.control_parser.citation_db_id = citation['id'].strip()
                 parser.control_parser.evidence = summary_text
                 parser.control_parser.annotations.update(evidence[EXPERIMENT_CONTEXT])
 
                 try:
                     parser.parseString(bel_statement, line_number=i)
                 except Exception as e:
-                    log.warning('JGIF relation parse error: %s for %s', e, bel_statement)
+                    logger.warning('JGIF relation parse error: %s for %s', e, bel_statement)
 
     return graph
 
 
+@open_file(0, mode='r')
+def from_jgif_file(path: Union[str, TextIO]) -> BELGraph:
+    """Build a graph from the JGIF JSON contained in the given file.
+
+    :param path: A path or file-like
+    """
+    return from_jgif(json.load(path))
+
+
+def from_jgif_gz(path: str) -> BELGraph:
+    """Read a graph as JGIF JSON from a gzip file."""
+    with gzip.open(path, 'rt') as file:
+        return from_jgif(json.load(file))
+
+
+def from_jgif_jsons(graph_json_str: str) -> BELGraph:
+    """Read a BEL graph from a JGIF JSON string."""
+    return from_jgif(json.loads(graph_json_str))
+
+
 def to_jgif(graph):
     """Build a JGIF dictionary from a BEL graph.
 
@@ -304,36 +327,30 @@ def to_jgif(graph):
         use Cytoscape.js, we suggest using :func:`pybel.to_cx` instead.
 
     Example:
-
     >>> import pybel, os, json
     >>> graph_url = 'https://arty.scai.fraunhofer.de/artifactory/bel/knowledge/selventa-small-corpus/selventa-small-corpus-20150611.bel'
-    >>> graph = pybel.from_url(graph_url)
+    >>> graph = pybel.from_bel_script_url(graph_url)
     >>> graph_jgif_json = pybel.to_jgif(graph)
     >>> with open(os.path.expanduser('~/Desktop/small_corpus.json'), 'w') as f:
     ...     json.dump(graph_jgif_json, f)
+
     """
-    node_bel = {}
     u_v_r_bel = {}
 
     nodes_entry = []
     edges_entry = []
 
-    for i, node in enumerate(sorted(graph, key=methodcaller('as_bel'))):
-        node_bel[node] = bel = node.as_bel()
-
+    for node in sorted(graph, key=methodcaller('as_bel')):
         nodes_entry.append({
-            'id': bel,
-            'label': bel,
-            'nodeId': i,
-            'bel_function_type': node[FUNCTION],
-            'metadata': {}
+            'id': node.md5,
+            'label': node.as_bel(),
+            'bel_function_type': node.function,
         })
 
     for u, v in graph.edges():
         relation_evidences = defaultdict(list)
 
-        for data in graph[u][v].values():
-
+        for key, data in graph[u][v].items():
             if (u, v, data[RELATION]) not in u_v_r_bel:
                 u_v_r_bel[u, v, data[RELATION]] = graph.edge_to_bel(u, v, edge_data=data)
 
@@ -341,6 +358,7 @@ def to_jgif(graph):
 
             evidence_dict = {
                 'bel_statement': bel,
+                'key': key,
             }
 
             if ANNOTATIONS in data:
@@ -356,19 +374,44 @@ def to_jgif(graph):
 
         for relation, evidences in relation_evidences.items():
             edges_entry.append({
-                'source': node_bel[u],
-                'target': node_bel[v],
+                'source': u.md5,
+                'target': v.md5,
                 'relation': relation,
                 'label': u_v_r_bel[u, v, relation],
                 'metadata': {
-                    'evidences': evidences
-                }
+                    'evidences': evidences,
+                },
             })
 
     return {
         'graph': {
-            'metadata': graph.document,
+            'metadata': dict(
+                origin=dict(name='pybel', version=get_version()),
+                **graph.document,
+            ),
             'nodes': nodes_entry,
-            'edges': edges_entry
-        }
+            'edges': edges_entry,
+        },
     }
+
+
+@open_file(1, mode='w')
+def to_jgif_file(graph: BELGraph, file: Union[str, TextIO], **kwargs) -> None:
+    """Write JGIF to a file."""
+    json.dump(to_jgif(graph), file, ensure_ascii=False, **kwargs)
+
+
+def to_jgif_gz(graph, path: str, **kwargs) -> None:
+    """Write a graph as JGIF JSON to a gzip file."""
+    with gzip.open(path, 'wt') as file:
+        json.dump(to_jgif(graph), file, ensure_ascii=False, **kwargs)
+
+
+def to_jgif_jsons(graph: BELGraph, **kwargs) -> str:
+    """Dump this graph as a JGIF JSON object to a string."""
+    return json.dumps(to_jgif(graph), ensure_ascii=False, **kwargs)
+
+
+def post_jgif(graph: BELGraph, url: str, **kwargs) -> requests.Response:
+    """Post the JGIF to a given URL."""
+    return requests.post(url, json=to_jgif(graph), **kwargs)
