@@ -7,11 +7,11 @@ import re
 import time
 from datetime import datetime
 from itertools import zip_longest
-from typing import Iterable, List
+from typing import Dict, Iterable, List, Optional, Set, Tuple, Union
 
 import requests
 
-from ..constants import CITATION, CITATION_REFERENCE, CITATION_TYPE_PUBMED
+from ..constants import CITATION, CITATION_IDENTIFIER, CITATION_TYPE_PUBMED
 from ..struct.filters import filter_edges
 from ..struct.filters.edge_predicates import has_pubmed
 from ..struct.summary.provenance import get_pubmed_identifiers
@@ -21,7 +21,7 @@ __all__ = [
     'enrich_pubmed_citations',
 ]
 
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 EUTILS_URL_FMT = "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/esummary.fcgi?db=pubmed&retmode=json&id={}"
 
@@ -81,18 +81,20 @@ def clean_pubmed_identifiers(pmids: Iterable[str]) -> List[str]:
     return sorted({str(pmid).strip() for pmid in pmids})
 
 
-def get_pubmed_citation_response(pubmed_identifiers):
+def get_pubmed_citation_response(pubmed_identifiers: Iterable[str]):
     """Get the response from PubMed E-Utils for a given list of PubMed identifiers.
 
-    :param list[str] pubmed_identifiers:
+    :param pubmed_identifiers:
     :rtype: dict
     """
     pubmed_identifiers = list(pubmed_identifiers)
-    url = EUTILS_URL_FMT.format(','.join(
-        pubmed_identifier
-        for pubmed_identifier in pubmed_identifiers
-        if pubmed_identifier
-    ))
+    url = EUTILS_URL_FMT.format(
+        ','.join(
+            pubmed_identifier
+            for pubmed_identifier in pubmed_identifiers
+            if pubmed_identifier
+        ),
+    )
     response = requests.get(url)
     return response.json()
 
@@ -105,11 +107,11 @@ def enrich_citation_model(manager, citation, p) -> bool:
     :param dict p: The dictionary from PubMed E-Utils corresponding to d["result"][pmid]
     """
     if 'error' in p:
-        log.warning('Error downloading PubMed')
+        logger.warning('Error downloading PubMed')
         return False
 
-    citation.name = p['fulljournalname']
     citation.title = p['title']
+    citation.journal = p['fulljournalname']
     citation.volume = p['volume']
     citation.issue = p['issue']
     citation.pages = p['pages']
@@ -123,41 +125,43 @@ def enrich_citation_model(manager, citation, p) -> bool:
                 citation.authors.append(author_model)
 
     publication_date = p['pubdate']
-
     sanitized_publication_date = sanitize_date(publication_date)
     if sanitized_publication_date:
         citation.date = datetime.strptime(sanitized_publication_date, '%Y-%m-%d')
     else:
-        log.info('result had date with strange format: %s', publication_date)
+        logger.info('result had date with strange format: %s', publication_date)
 
     return True
 
 
-def get_citations_by_pmids(manager, pmids, group_size=None, sleep_time=None):
+def get_citations_by_pmids(
+    manager,
+    pmids: Iterable[Union[str, int]],
+    group_size: Optional[int] = None,
+    sleep_time: Optional[int] = None,
+) -> Tuple[Dict[str, Dict], Set[str]]:
     """Get citation information for the given list of PubMed identifiers using the NCBI's eUtils service.
 
     :type manager: pybel.Manager
     :param pmids: an iterable of PubMed identifiers
-    :type pmids: iter[str] or iter[int]
-    :param int group_size: The number of PubMed identifiers to query at a time. Defaults to 200 identifiers.
-    :param int sleep_time: Number of seconds to sleep between queries. Defaults to 1 second.
+    :param group_size: The number of PubMed identifiers to query at a time. Defaults to 200 identifiers.
+    :param sleep_time: Number of seconds to sleep between queries. Defaults to 1 second.
     :return: A dictionary of {pmid: pmid data dictionary} or a pair of this dictionary and a set ot erroneous
             pmids if return_errors is :data:`True`
-    :rtype: tuple[dict[str,dict],set[str]]
     """
     group_size = group_size if group_size is not None else 200
     sleep_time = sleep_time if sleep_time is not None else 1
 
     pmids = clean_pubmed_identifiers(pmids)
-    log.info('Ensuring %d PubMed identifiers', len(pmids))
+    logger.info('Ensuring %d PubMed identifiers', len(pmids))
 
     result = {}
     unenriched_pmids = {}
 
     for pmid in pmids:
-        citation = manager.get_or_create_citation(type=CITATION_TYPE_PUBMED, reference=pmid)
+        citation = manager.get_or_create_citation(db=CITATION_TYPE_PUBMED, db_id=pmid)
 
-        if not citation.date or not citation.name or not citation.authors:
+        if not citation.is_enriched:
             unenriched_pmids[pmid] = citation
             continue
 
@@ -165,20 +169,20 @@ def get_citations_by_pmids(manager, pmids, group_size=None, sleep_time=None):
 
     manager.session.commit()
 
-    log.debug('Found %d PubMed identifiers in database', len(pmids) - len(unenriched_pmids))
+    logger.debug('Found %d PubMed identifiers in database', len(pmids) - len(unenriched_pmids))
 
     if not unenriched_pmids:
         return result, set()
 
     number_unenriched = len(unenriched_pmids)
-    log.info('Querying PubMed for %d identifiers', number_unenriched)
+    logger.info('Querying PubMed for %d identifiers', number_unenriched)
 
     errors = set()
     t = time.time()
 
     for pmid_group_index, pmid_list in enumerate(grouper(group_size, unenriched_pmids), start=1):
         pmid_list = list(pmid_list)
-        log.info('Getting group %d having %d PubMed identifiers', pmid_group_index, len(pmid_list))
+        logger.info('Getting group %d having %d PubMed identifiers', pmid_group_index, len(pmid_list))
 
         response = get_pubmed_citation_response(pmid_list)
         response_pmids = response['result']['uids']
@@ -190,7 +194,7 @@ def get_citations_by_pmids(manager, pmids, group_size=None, sleep_time=None):
             successful_enrichment = enrich_citation_model(manager, citation, p)
 
             if not successful_enrichment:
-                log.warning("Error downloading PubMed identifier: %s", pmid)
+                logger.warning("Error downloading PubMed identifier: %s", pmid)
                 errors.add(pmid)
                 continue
 
@@ -202,12 +206,17 @@ def get_citations_by_pmids(manager, pmids, group_size=None, sleep_time=None):
         # Don't want to hit that rate limit
         time.sleep(sleep_time)
 
-    log.info('retrieved %d PubMed identifiers in %.02f seconds', len(unenriched_pmids), time.time() - t)
+    logger.info('retrieved %d PubMed identifiers in %.02f seconds', len(unenriched_pmids), time.time() - t)
 
     return result, errors
 
 
-def enrich_pubmed_citations(manager, graph, group_size=None, sleep_time=None):
+def enrich_pubmed_citations(
+    manager,
+    graph,
+    group_size: Optional[int] = None,
+    sleep_time: Optional[int] = None,
+) -> Set[str]:
     """Overwrite all PubMed citations with values from NCBI's eUtils lookup service.
 
     Sets authors as list, so probably a good idea to run :func:`pybel_tools.mutation.serialize_authors` before
@@ -215,19 +224,18 @@ def enrich_pubmed_citations(manager, graph, group_size=None, sleep_time=None):
 
     :type manager: pybel.manager.Manager
     :type graph: pybel.BELGraph
-    :param Optional[int] group_size: The number of PubMed identifiers to query at a time. Defaults to 200 identifiers.
-    :param Optional[int] sleep_time: Number of seconds to sleep between queries. Defaults to 1 second.
+    :param group_size: The number of PubMed identifiers to query at a time. Defaults to 200 identifiers.
+    :param sleep_time: Number of seconds to sleep between queries. Defaults to 1 second.
     :return: A set of PMIDs for which the eUtils service crashed
-    :rtype: set[str]
     """
     pmids = get_pubmed_identifiers(graph)
     pmid_data, errors = get_citations_by_pmids(manager, pmids=pmids, group_size=group_size, sleep_time=sleep_time)
 
     for u, v, k in filter_edges(graph, has_pubmed):
-        pmid = graph[u][v][k][CITATION][CITATION_REFERENCE].strip()
+        pmid = graph[u][v][k][CITATION][CITATION_IDENTIFIER].strip()
 
         if pmid not in pmid_data:
-            log.warning('Missing data for PubMed identifier: %s', pmid)
+            logger.warning('Missing data for PubMed identifier: %s', pmid)
             errors.add(pmid)
             continue
 
