@@ -11,30 +11,31 @@ from typing import Dict, List, Mapping, Optional, Pattern, Set, Union
 
 import pyparsing
 from pyparsing import (
-    And, Group, Keyword, MatchFirst, ParseResults, StringEnd, Suppress, delimitedList, oneOf, replaceWith,
+    Group, Keyword, MatchFirst, ParseResults, StringEnd, Suppress, delimitedList, oneOf, replaceWith,
 )
 
 from .baseparser import BaseParser
+from .constants import NamespaceTermEncodingMapping
 from .exc import (
     InvalidEntity, InvalidFunctionSemantic, MalformedTranslocationWarning, MissingAnnotationWarning,
-    MissingCitationException, MissingSupportWarning, NestedRelationWarning, RelabelWarning,
+    MissingCitationException, MissingSupportWarning, NestedRelationWarning,
 )
 from .modifiers import (
     get_fragment_language, get_fusion_language, get_gene_modification_language, get_gene_substitution_language,
     get_hgvs_language, get_legacy_fusion_langauge, get_location_language, get_protein_modification_language,
     get_protein_substitution_language, get_truncation_language,
 )
+from .parse_concept import ConceptParser
 from .parse_control import ControlParser
-from .parse_identifier import IdentifierParser
-from .utils import WCW, nest, one_of_tags, quote, triple
+from .utils import WCW, nest, one_of_tags, triple
 from .. import language
 from ..constants import (
-    ABUNDANCE, ACTIVITY, ASSOCIATION, BEL_DEFAULT_NAMESPACE, BIOPROCESS, CAUSES_NO_CHANGE, CELL_SECRETION,
-    CELL_SURFACE_EXPRESSION, COMPLEX, COMPOSITE, DECREASES, DEGRADATION, DIRECTLY_DECREASES, DIRECTLY_INCREASES, DIRTY,
-    EFFECT, EQUIVALENT_TO, FROM_LOC, FUNCTION, FUSION, GENE, HAS_COMPONENT, HAS_MEMBER, IDENTIFIER, INCREASES, IS_A,
-    LINE, LOCATION, MEMBERS, MIRNA, MODIFIER, NAME, NAMESPACE, NEGATIVE_CORRELATION, OBJECT, PART_OF, PATHOLOGY,
-    POSITIVE_CORRELATION, PRODUCTS, PROTEIN, REACTANTS, REACTION, REGULATES, RELATION, RNA, SUBJECT, TARGET, TO_LOC,
-    TRANSCRIBED_TO, TRANSLATED_TO, TRANSLOCATION, TWO_WAY_RELATIONS, VARIANTS, belns_encodings,
+    ABUNDANCE, ACTIVITY, ASSOCIATION, BEL_DEFAULT_NAMESPACE, BINDS, BIOPROCESS, CAUSES_NO_CHANGE, CELL_SECRETION,
+    CELL_SURFACE_EXPRESSION, COMPLEX, COMPOSITE, CONCEPT, CORRELATION, DECREASES, DEGRADATION, DIRECTLY_DECREASES,
+    DIRECTLY_INCREASES, DIRTY, EFFECT, EQUIVALENT_TO, FROM_LOC, FUNCTION, FUSION, GENE, INCREASES, IS_A, LINE, LOCATION,
+    MEMBERS, MIRNA, MODIFIER, NAME, NAMESPACE, NEGATIVE_CORRELATION, NO_CORRELATION, OBJECT, PART_OF, PATHOLOGY,
+    POPULATION, POSITIVE_CORRELATION, PRODUCTS, PROTEIN, REACTANTS, REACTION, REGULATES, RELATION, RNA, SUBJECT, TARGET,
+    TO_LOC, TRANSCRIBED_TO, TRANSLATED_TO, TRANSLOCATION, TWO_WAY_RELATIONS, VARIANTS, belns_encodings,
 )
 from ..dsl import BaseEntity, cell_surface_expression, secretion
 from ..tokens import parse_result_to_dsl
@@ -44,7 +45,7 @@ __all__ = [
     'modifier_po_to_dict',
 ]
 
-log = logging.getLogger('pybel.parser')
+logger = logging.getLogger('pybel.parser')
 
 ###########################
 # 2.1 Abundance Functions #
@@ -109,6 +110,8 @@ biological_process_tag = one_of_tags(['bp', 'biologicalProcess'], BIOPROCESS, FU
 #: 2.3.2 http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_pathology_path
 pathology_tag = one_of_tags(['o', 'path', 'pathology'], PATHOLOGY, FUNCTION)
 
+population_tag = one_of_tags(['pop', 'populationAbundance'], POPULATION, FUNCTION)
+
 #: 2.3.3 http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#Xactivity
 activity_tag = one_of_tags(['act', 'activity'], ACTIVITY, MODIFIER)
 
@@ -159,6 +162,15 @@ causes_no_change_tag = one_of_tags(['cnc', 'causesNoChange'], CAUSES_NO_CHANGE)
 #: `3.1.7 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_regulates_reg>`_
 regulates_tag = one_of_tags(['reg', 'regulates'], REGULATES)
 
+#: Binds relation
+binds_tag = Keyword(BINDS)
+
+#: Correlation relation
+correlation_tag = one_of_tags(['cor', 'correlation'], CORRELATION)
+
+#: No Correlation relation
+no_correlation_tag = one_of_tags(['noCor', 'noCorrelation'], NO_CORRELATION)
+
 #: `3.2.1 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XnegCor>`_
 negative_correlation_tag = one_of_tags(['neg', 'negativeCorrelation'], NEGATIVE_CORRELATION)
 
@@ -222,25 +234,26 @@ partof_tag = Keyword(PART_OF)
 class BELParser(BaseParser):
     """Build a parser backed by a given dictionary of namespaces."""
 
-    def __init__(self,
-                 graph,
-                 namespace_to_term: Optional[Mapping[str, Mapping[str, str]]] = None,
-                 namespace_to_pattern: Optional[Mapping[str, Pattern]] = None,
-                 annotation_to_term: Optional[Mapping[str, Set[str]]] = None,
-                 annotation_to_pattern: Optional[Mapping[str, Pattern]] = None,
-                 annotation_to_local: Optional[Mapping[str, Set[str]]] = None,
-                 allow_naked_names: bool = False,
-                 allow_nested: bool = False,
-                 disallow_unqualified_translocations: bool = False,
-                 citation_clearing: bool = True,
-                 skip_validation: bool = False,
-                 autostreamline: bool = True,
-                 required_annotations: Optional[List[str]] = None,
-                 ) -> None:
+    def __init__(
+        self,
+        graph,
+        namespace_to_term_to_encoding: Optional[NamespaceTermEncodingMapping] = None,
+        namespace_to_pattern: Optional[Mapping[str, Pattern]] = None,
+        annotation_to_term: Optional[Mapping[str, Set[str]]] = None,
+        annotation_to_pattern: Optional[Mapping[str, Pattern]] = None,
+        annotation_to_local: Optional[Mapping[str, Set[str]]] = None,
+        allow_naked_names: bool = False,
+        disallow_nested: bool = False,
+        disallow_unqualified_translocations: bool = False,
+        citation_clearing: bool = True,
+        skip_validation: bool = False,
+        autostreamline: bool = True,
+        required_annotations: Optional[List[str]] = None,
+    ) -> None:
         """Build a BEL parser.
 
         :param pybel.BELGraph graph: The BEL Graph to use to store the network
-        :param namespace_to_term: A dictionary of {namespace: {name: encoding}}. Delegated to
+        :param namespace_to_term_to_encoding: A dictionary of {namespace: {name: encoding}}. Delegated to
          :class:`pybel.parser.parse_identifier.IdentifierParser`
         :param namespace_to_pattern: A dictionary of {namespace: regular expression strings}. Delegated to
          :class:`pybel.parser.parse_identifier.IdentifierParser`
@@ -252,7 +265,7 @@ class BELParser(BaseParser):
          :class:`pybel.parser.ControlParser`
         :param allow_naked_names: If true, turn off naked namespace failures. Delegated to
          :class:`pybel.parser.parse_identifier.IdentifierParser`
-        :param allow_nested: If true, turn off nested statement failures. Delegated to
+        :param disallow_nested: If true, turn on nested statement failures. Delegated to
          :class:`pybel.parser.parse_identifier.IdentifierParser`
         :param disallow_unqualified_translocations: If true, allow translocations without TO and FROM clauses.
         :param citation_clearing: Should :code:`SET Citation` statements clear evidence and all annotations?
@@ -261,8 +274,9 @@ class BELParser(BaseParser):
         :param required_annotations: Optional list of required annotations
         """
         self.graph = graph
+        self.metagraph = set()
 
-        self.allow_nested = allow_nested
+        self.disallow_nested = disallow_nested
         self.disallow_unqualified_translocations = disallow_unqualified_translocations
 
         if skip_validation:
@@ -271,7 +285,7 @@ class BELParser(BaseParser):
                 required_annotations=required_annotations,
             )
 
-            self.identifier_parser = IdentifierParser(
+            self.concept_parser = ConceptParser(
                 allow_naked_names=allow_naked_names,
             )
         else:
@@ -283,98 +297,108 @@ class BELParser(BaseParser):
                 required_annotations=required_annotations,
             )
 
-            self.identifier_parser = IdentifierParser(
+            self.concept_parser = ConceptParser(
                 allow_naked_names=allow_naked_names,
-                namespace_to_term=namespace_to_term,
+                namespace_to_term_to_encoding=namespace_to_term_to_encoding,
                 namespace_to_pattern=namespace_to_pattern,
             )
 
         self.control_parser.get_line_number = self.get_line_number
-        self.identifier_parser.get_line_number = self.get_line_number
+        self.concept_parser.get_line_number = self.get_line_number
 
-        identifier = Group(self.identifier_parser.language)(IDENTIFIER)
-        ungrouped_identifier = self.identifier_parser.language
+        concept = Group(self.concept_parser.language)(CONCEPT)
 
         # 2.2 Abundance Modifier Functions
 
         #: `2.2.1 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_protein_modifications>`_
-        self.pmod = get_protein_modification_language(self.identifier_parser.identifier_qualified)
+        self.pmod = get_protein_modification_language(self.concept_parser.identifier_qualified)
 
         #: `2.2.4 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_cellular_location>`_
-        self.location = get_location_language(self.identifier_parser.language)
+        self.location = get_location_language(self.concept_parser.language)
         opt_location = pyparsing.Optional(WCW + self.location)
 
         #: PyBEL BEL Specification variant
-        self.gmod = get_gene_modification_language(self.identifier_parser.identifier_qualified)
+        self.gmod = get_gene_modification_language(self.concept_parser.identifier_qualified)
 
         # 2.6 Other Functions
 
         #: `2.6.1 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_fusion_fus>`_
-        self.fusion = get_fusion_language(self.identifier_parser.language)
+        self.fusion = get_fusion_language(self.concept_parser.language)
 
         # 2.1 Abundance Functions
 
         #: `2.1.1 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XcomplexA>`_
-        self.general_abundance = general_abundance_tags + nest(ungrouped_identifier + opt_location)
+        self.general_abundance = general_abundance_tags + nest(concept + opt_location)
 
-        self.gene_modified = ungrouped_identifier + pyparsing.Optional(
-            WCW + delimitedList(Group(variant | gsub | self.gmod))(VARIANTS))
+        self.gene_modified = concept + pyparsing.Optional(
+            WCW + delimitedList(Group(variant | gsub | self.gmod))(VARIANTS),
+        )
 
         self.gene_fusion = Group(self.fusion)(FUSION)
-        self.gene_fusion_legacy = Group(get_legacy_fusion_langauge(identifier, 'c'))(FUSION)
+        self.gene_fusion_legacy = Group(get_legacy_fusion_langauge(concept, 'c'))(FUSION)
 
         #: `2.1.4 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XgeneA>`_
-        self.gene = gene_tag + nest(MatchFirst([
-            self.gene_fusion,
-            self.gene_fusion_legacy,
-            self.gene_modified
-        ]) + opt_location)
+        self.gene = gene_tag + nest(
+            MatchFirst([
+                self.gene_fusion,
+                self.gene_fusion_legacy,
+                self.gene_modified,
+            ]) + opt_location,
+        )
 
-        self.mirna_modified = ungrouped_identifier + pyparsing.Optional(
-            WCW + delimitedList(Group(variant))(VARIANTS)) + opt_location
+        self.mirna_modified = concept + pyparsing.Optional(
+            WCW + delimitedList(Group(variant))(VARIANTS),
+        ) + opt_location
 
         #: `2.1.5 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XmicroRNAA>`_
         self.mirna = mirna_tag + nest(self.mirna_modified)
 
-        self.protein_modified = ungrouped_identifier + pyparsing.Optional(
+        self.protein_modified = concept + pyparsing.Optional(
             WCW + delimitedList(Group(MatchFirst([self.pmod, variant, fragment, psub, trunc])))(
-                VARIANTS))
+                VARIANTS,
+            ),
+        )
 
         self.protein_fusion = Group(self.fusion)(FUSION)
-        self.protein_fusion_legacy = Group(get_legacy_fusion_langauge(identifier, 'p'))(FUSION)
+        self.protein_fusion_legacy = Group(get_legacy_fusion_langauge(concept, 'p'))(FUSION)
 
         #: `2.1.6 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XproteinA>`_
-        self.protein = protein_tag + nest(MatchFirst([
-            self.protein_fusion,
-            self.protein_fusion_legacy,
-            self.protein_modified,
-        ]) + opt_location)
+        self.protein = protein_tag + nest(
+            MatchFirst([
+                self.protein_fusion,
+                self.protein_fusion_legacy,
+                self.protein_modified,
+            ]) + opt_location,
+        )
 
-        self.rna_modified = ungrouped_identifier + pyparsing.Optional(WCW + delimitedList(Group(variant))(VARIANTS))
+        self.rna_modified = concept + pyparsing.Optional(WCW + delimitedList(Group(variant))(VARIANTS))
 
         self.rna_fusion = Group(self.fusion)(FUSION)
-        self.rna_fusion_legacy = Group(get_legacy_fusion_langauge(identifier, 'r'))(FUSION)
+        self.rna_fusion_legacy = Group(get_legacy_fusion_langauge(concept, 'r'))(FUSION)
 
         #: `2.1.7 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XrnaA>`_
-        self.rna = rna_tag + nest(MatchFirst([
-            self.rna_fusion,
-            self.rna_fusion_legacy,
-            self.rna_modified,
-        ]) + opt_location)
+        self.rna = rna_tag + nest(
+            MatchFirst([
+                self.rna_fusion,
+                self.rna_fusion_legacy,
+                self.rna_modified,
+            ]) + opt_location,
+        )
 
         self.single_abundance = MatchFirst([
             self.general_abundance,
             self.gene,
             self.mirna,
             self.protein,
-            self.rna
+            self.rna,
         ])
 
         #: `2.1.2 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XcomplexA>`_
-        self.complex_singleton = complex_tag + nest(ungrouped_identifier + opt_location)
+        self.complex_singleton = complex_tag + nest(concept + opt_location)
 
         self.complex_list = complex_tag + nest(
-            delimitedList(Group(self.single_abundance | self.complex_singleton))(MEMBERS) + opt_location)
+            delimitedList(Group(self.single_abundance | self.complex_singleton))(MEMBERS) + opt_location,
+        )
 
         self.complex_abundances = self.complex_list | self.complex_singleton
 
@@ -384,8 +408,7 @@ class BELParser(BaseParser):
 
         #: `2.1.3 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XcompositeA>`_
         self.composite_abundance = composite_abundance_tag + nest(
-            delimitedList(Group(self.simple_abundance))(MEMBERS) +
-            opt_location
+            delimitedList(Group(self.simple_abundance))(MEMBERS) + opt_location,
         )
 
         self.abundance = self.simple_abundance | self.composite_abundance
@@ -394,28 +417,29 @@ class BELParser(BaseParser):
         # backwards compatibility with BEL v1.0
 
         molecular_activity_default = oneOf(list(language.activity_labels)).setParseAction(
-            handle_molecular_activity_default)
+            handle_molecular_activity_default,
+        )
 
         #: `2.4.1 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XmolecularA>`_
         self.molecular_activity = molecular_activity_tags + nest(
-            molecular_activity_default |
-            self.identifier_parser.language
+            molecular_activity_default | self.concept_parser.language,
         )
 
         # 2.3 Process Functions
 
         #: `2.3.1 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_biologicalprocess_bp>`_
-        self.biological_process = biological_process_tag + nest(ungrouped_identifier)
+        self.biological_process = biological_process_tag + nest(concept)
 
         #: `2.3.2 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_pathology_path>`_
-        self.pathology = pathology_tag + nest(ungrouped_identifier)
+        self.pathology = pathology_tag + nest(concept)
 
-        self.bp_path = self.biological_process | self.pathology
+        self.population = population_tag + nest(concept)
+
+        self.bp_path = self.biological_process | self.pathology | self.population
         self.bp_path.setParseAction(self.check_function_semantics)
 
         self.activity_standard = activity_tag + nest(
-            Group(self.simple_abundance)(TARGET) +
-            pyparsing.Optional(WCW + Group(self.molecular_activity)(EFFECT))
+            Group(self.simple_abundance)(TARGET) + pyparsing.Optional(WCW + Group(self.molecular_activity)(EFFECT)),
         )
 
         activity_legacy_tags = oneOf(language.activities)(MODIFIER)
@@ -429,23 +453,23 @@ class BELParser(BaseParser):
 
         # 2.5 Transformation Functions
 
-        from_loc = Suppress(FROM_LOC) + nest(identifier(FROM_LOC))
-        to_loc = Suppress(TO_LOC) + nest(identifier(TO_LOC))
+        from_loc = Suppress(FROM_LOC) + nest(concept(FROM_LOC))
+        to_loc = Suppress(TO_LOC) + nest(concept(TO_LOC))
 
         self.cell_secretion = cell_secretion_tag + nest(Group(self.simple_abundance)(TARGET))
 
         self.cell_surface_expression = cell_surface_expression_tag + nest(Group(self.simple_abundance)(TARGET))
 
         self.translocation_standard = nest(
-            Group(self.simple_abundance)(TARGET) +
-            WCW +
-            Group(from_loc + WCW + to_loc)(EFFECT)
+            Group(self.simple_abundance)(TARGET)
+            + WCW
+            + Group(from_loc + WCW + to_loc)(EFFECT),
         )
 
         self.translocation_legacy = nest(
-            Group(self.simple_abundance)(TARGET) +
-            WCW +
-            Group(identifier(FROM_LOC) + WCW + identifier(TO_LOC))(EFFECT)
+            Group(self.simple_abundance)(TARGET)
+            + WCW
+            + Group(concept(FROM_LOC) + WCW + concept(TO_LOC))(EFFECT),
         )
 
         self.translocation_legacy.addParseAction(handle_legacy_tloc)
@@ -458,7 +482,7 @@ class BELParser(BaseParser):
         self.translocation = translocation_tag + MatchFirst([
             self.translocation_unqualified,
             self.translocation_standard,
-            self.translocation_legacy
+            self.translocation_legacy,
         ])
 
         #: `2.5.2 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_degradation_deg>`_
@@ -475,7 +499,7 @@ class BELParser(BaseParser):
             self.cell_surface_expression,
             self.translocation,
             self.degradation,
-            self.reaction
+            self.reaction,
         ])
 
         # 3 BEL Relationships
@@ -488,6 +512,9 @@ class BELParser(BaseParser):
             decreases_tag,
             positive_correlation_tag,
             negative_correlation_tag,
+            correlation_tag,
+            no_correlation_tag,
+            binds_tag,
             causes_no_change_tag,
             orthologous_tag,
             is_a_tag,
@@ -506,14 +533,14 @@ class BELParser(BaseParser):
         self.rate_limit = triple(
             MatchFirst([self.biological_process, self.activity, self.transformation]),
             rate_limit_tag,
-            self.biological_process
+            self.biological_process,
         )
 
         #: `3.4.6 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_subprocessof>`_
         self.subprocess_of = triple(
             MatchFirst([self.process, self.activity, self.transformation]),
             subprocess_of_tag,
-            self.process
+            self.process,
         )
 
         #: `3.3.2 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_transcribedto>`_
@@ -538,9 +565,9 @@ class BELParser(BaseParser):
 
         # `3.4.3 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_hascomponent>`_
         self.has_component = triple(
-            self.complex_abundances | self.composite_abundance,
+            self.abundance,
             has_component_tag,
-            self.abundance
+            self.abundance,
         )
 
         self.biomarker = triple(self.bel_term, biomarker_tags, self.process)
@@ -560,44 +587,45 @@ class BELParser(BaseParser):
             # self.has_variant_relation,
             # self.part_of_reaction,
         ])
-
         self.relation.setParseAction(self._handle_relation_harness)
 
-        self.unqualified_relation = MatchFirst([
+        self.inverted_unqualified_relation = MatchFirst([
+            self.has_member,
+            self.has_component,
+        ])
+        self.inverted_unqualified_relation.setParseAction(self.handle_inverse_unqualified_relation)
+
+        self.normal_unqualified_relation = MatchFirst([
             self.has_member,
             self.has_component,
             self.has_variant_relation,
-            self.part_of_reaction
+            self.part_of_reaction,
         ])
+        self.normal_unqualified_relation.setParseAction(self.handle_unqualified_relation)
 
-        self.unqualified_relation.setParseAction(self.handle_unqualified_relation)
-
-        #: 3.1 Causal Relationships - nested. Not enabled by default.
+        #: 3.1 Causal Relationships - nested.
         causal_relation_tags = MatchFirst([
             increases_tag,
             decreases_tag,
             directly_decreases_tag,
-            directly_increases_tag
+            directly_increases_tag,
         ])
 
         self.nested_causal_relationship = triple(
             self.bel_term,
             causal_relation_tags,
-            nest(triple(self.bel_term, causal_relation_tags, self.bel_term))
+            nest(triple(self.bel_term, causal_relation_tags, self.bel_term)),
         )
 
         self.nested_causal_relationship.setParseAction(self.handle_nested_relation)
 
-        self.label_relationship = And([Group(self.bel_term)(SUBJECT), Suppress('labeled'), quote(OBJECT)])
-        self.label_relationship.setParseAction(self.handle_label_relation)
-
         # has_members is handled differently from all other relations becuase it gets distrinbuted
         self.relation = MatchFirst([
             self.has_list,
             self.nested_causal_relationship,
             self.relation,
-            self.unqualified_relation,
-            self.label_relationship,
+            self.inverted_unqualified_relation,
+            self.normal_unqualified_relation,
         ])
 
         self.singleton_term = (self.bel_term + StringEnd()).setParseAction(self.handle_term)
@@ -611,12 +639,12 @@ class BELParser(BaseParser):
     @property
     def _namespace_dict(self) -> Mapping[str, Mapping[str, str]]:
         """Get the dictionary of {namespace: {name: encoding}} stored in the internal identifier parser."""
-        return self.identifier_parser.namespace_to_terms
+        return self.concept_parser.namespace_to_name_to_encoding
 
     @property
     def _allow_naked_names(self) -> bool:
         """Return if naked names should be parsed (``True``), or if errors should be thrown (``False``)."""
-        return self.identifier_parser.allow_naked_names
+        return self.concept_parser.allow_naked_names
 
     def get_annotations(self) -> Dict:
         """Get the current annotations in this parser."""
@@ -630,24 +658,29 @@ class BELParser(BaseParser):
     def handle_nested_relation(self, line: str, position: int, tokens: ParseResults):
         """Handle nested statements.
 
-        If :code:`allow_nested` is False, raises a ``NestedRelationWarning``.
+        If :code:`self.disallow_nested` is True, raises a ``NestedRelationWarning``.
 
         :raises: NestedRelationWarning
         """
-        if not self.allow_nested:
+        if self.disallow_nested:
             raise NestedRelationWarning(self.get_line_number(), line, position)
 
-        self._handle_relation_harness(line, position, {
-            SUBJECT: tokens[SUBJECT],
-            RELATION: tokens[RELATION],
-            OBJECT: tokens[OBJECT][SUBJECT],
-        })
+        subject_hash = self._handle_relation_checked(
+            line, position, {
+                SUBJECT: tokens[SUBJECT],
+                RELATION: tokens[RELATION],
+                OBJECT: tokens[OBJECT][SUBJECT],
+            },
+        )
 
-        self._handle_relation_harness(line, position, {
-            SUBJECT: tokens[OBJECT][SUBJECT],
-            RELATION: tokens[OBJECT][RELATION],
-            OBJECT: tokens[OBJECT][OBJECT],
-        })
+        object_hash = self._handle_relation_checked(
+            line, position, {
+                SUBJECT: tokens[OBJECT][SUBJECT],
+                RELATION: tokens[OBJECT][RELATION],
+                OBJECT: tokens[OBJECT][OBJECT],
+            },
+        )
+        self.metagraph.add((subject_hash, object_hash))
         return tokens
 
     def check_function_semantics(self, line: str, position: int, tokens: ParseResults) -> ParseResults:
@@ -655,28 +688,38 @@ class BELParser(BaseParser):
 
         :raises: InvalidFunctionSemantic
         """
-        if not self._namespace_dict or NAMESPACE not in tokens:
+        concept = tokens.get(CONCEPT)
+        if not self._namespace_dict or concept is None:
             return tokens
 
-        namespace, name = tokens[NAMESPACE], tokens[NAME]
+        namespace, name = concept[NAMESPACE], concept[NAME]
 
-        if namespace in self.identifier_parser.namespace_to_pattern:
+        if namespace in self.concept_parser.namespace_to_pattern:
             return tokens
 
-        if self._allow_naked_names and tokens[NAMESPACE] == DIRTY:  # Don't check dirty names in lenient mode
+        if self._allow_naked_names and namespace == DIRTY:  # Don't check dirty names in lenient mode
             return tokens
 
-        valid_functions = set(itt.chain.from_iterable(
-            belns_encodings.get(k, set())
-            for k in self._namespace_dict[namespace][name]
-        ))
+        valid_functions = set(
+            itt.chain.from_iterable(
+                belns_encodings.get(encoding, set())
+                for encoding in self._namespace_dict[namespace][name]
+            ),
+        )
 
         if not valid_functions:
             raise InvalidEntity(self.get_line_number(), line, position, namespace, name)
 
         if tokens[FUNCTION] not in valid_functions:
-            raise InvalidFunctionSemantic(self.get_line_number(), line, position, tokens[FUNCTION], namespace, name,
-                                          valid_functions)
+            raise InvalidFunctionSemantic(
+                line_number=self.get_line_number(),
+                line=line,
+                position=position,
+                func=tokens[FUNCTION],
+                namespace=namespace,
+                name=name,
+                allowed_functions=valid_functions,
+            )
 
         return tokens
 
@@ -691,64 +734,68 @@ class BELParser(BaseParser):
 
         for child_tokens in tokens[2]:
             child_node_dsl = self.ensure_node(child_tokens)
-            self.graph.add_unqualified_edge(parent_node_dsl, child_node_dsl, relation)
+            # Note that the polarity is switched since this is just for hasMembers
+            # and hasComponents, which are both deprecated as of BEL v2.2
+            self.graph.add_unqualified_edge(child_node_dsl, parent_node_dsl, relation)
 
         return tokens
 
     def handle_has_members(self, _, __, tokens: ParseResults) -> ParseResults:
         """Handle list relations like ``p(X) hasMembers list(p(Y), p(Z), ...)``."""
-        return self._handle_list_helper(tokens, HAS_MEMBER)
+        return self._handle_list_helper(tokens, IS_A)
 
     def handle_has_components(self, _, __, tokens: ParseResults) -> ParseResults:
         """Handle list relations like ``p(X) hasComponents list(p(Y), p(Z), ...)``."""
-        return self._handle_list_helper(tokens, HAS_COMPONENT)
+        return self._handle_list_helper(tokens, PART_OF)
 
-    def _add_qualified_edge_helper(self, u, v, relation, annotations, subject_modifier, object_modifier) -> str:
+    def _add_qualified_edge_helper(self, *, u, u_modifier, relation, v, v_modifier, annotations) -> str:
         """Add a qualified edge from the internal aspects of the parser."""
-        return self.graph.add_qualified_edge(
-            u,
-            v,
-            relation=relation,
+        m = {
+            BINDS: self.graph.add_binds,
+        }
+        adder = m.get(relation)
+        d = dict(
             evidence=self.control_parser.evidence,
-            citation=self.control_parser.citation.copy(),
+            citation=self.control_parser.get_citation(),
             annotations=annotations,
-            subject_modifier=subject_modifier,
-            object_modifier=object_modifier,
-            **{LINE: self.get_line_number()}
+            subject_modifier=u_modifier,
+            object_modifier=v_modifier,
+            **{LINE: self.get_line_number()},
         )
+        if adder is not None:
+            return adder(u=u, v=v, **d)
+        else:
+            return self.graph.add_qualified_edge(u=u, v=v, relation=relation, **d)
 
-    def _add_qualified_edge(self, u, v, relation, annotations, subject_modifier, object_modifier) -> str:
+    def _add_qualified_edge(self, *, u, u_modifier, relation, v, v_modifier, annotations) -> str:
         """Add an edge, then adds the opposite direction edge if it should."""
-        sha512 = self._add_qualified_edge_helper(
-            u,
-            v,
+        d = dict(
             relation=relation,
             annotations=annotations,
-            subject_modifier=subject_modifier,
-            object_modifier=object_modifier,
         )
-
         if relation in TWO_WAY_RELATIONS:
-            self._add_qualified_edge_helper(
-                v,
-                u,
-                relation=relation,
-                annotations=annotations,
-                object_modifier=subject_modifier,
-                subject_modifier=object_modifier,
-            )
-
-        return sha512
+            self._add_qualified_edge_helper(u=v, u_modifier=v_modifier, v=u, v_modifier=u_modifier, **d)
+        return self._add_qualified_edge_helper(u=u, u_modifier=u_modifier, v=v, v_modifier=v_modifier, **d)
 
     def _handle_relation(self, tokens: ParseResults) -> str:
         """Handle a relation."""
-        subject_node_dsl = self.ensure_node(tokens[SUBJECT])
-        object_node_dsl = self.ensure_node(tokens[OBJECT])
+        u = self.ensure_node(tokens[SUBJECT])
+        u_modifier = modifier_po_to_dict(tokens[SUBJECT])
+        relation = tokens[RELATION]
+        v = self.ensure_node(tokens[OBJECT])
+        v_modifier = modifier_po_to_dict(tokens[OBJECT])
 
-        subject_modifier = modifier_po_to_dict(tokens[SUBJECT])
-        object_modifier = modifier_po_to_dict(tokens[OBJECT])
+        annotations = self._get_prepared_annotations()
 
-        annotations = {
+        return self._add_qualified_edge(
+            u=u, u_modifier=u_modifier,
+            relation=relation,
+            v=v, v_modifier=v_modifier,
+            annotations=annotations,
+        )
+
+    def _get_prepared_annotations(self):
+        return {
             annotation_name: (
                 {
                     ae: True
@@ -756,27 +803,22 @@ class BELParser(BaseParser):
                 }
                 if isinstance(annotation_entry, set) else
                 {
-                    annotation_entry: True
+                    annotation_entry: True,
                 }
             )
             for annotation_name, annotation_entry in self.control_parser.annotations.items()
         }
 
-        return self._add_qualified_edge(
-            subject_node_dsl,
-            object_node_dsl,
-            relation=tokens[RELATION],
-            annotations=annotations,
-            subject_modifier=subject_modifier,
-            object_modifier=object_modifier,
-        )
-
     def _handle_relation_harness(self, line: str, position: int, tokens: Union[ParseResults, Dict]) -> ParseResults:
         """Handle BEL relations based on the policy specified on instantiation.
 
         Note: this can't be changed after instantiation!
         """
-        if not self.control_parser.citation:
+        self._handle_relation_checked(line, position, tokens)
+        return tokens
+
+    def _handle_relation_checked(self, line, position, tokens):
+        if not self.control_parser.citation_is_set:
             raise MissingCitationException(self.get_line_number(), line, position)
 
         if not self.control_parser.evidence:
@@ -786,36 +828,22 @@ class BELParser(BaseParser):
         if missing_required_annotations:
             raise MissingAnnotationWarning(self.get_line_number(), line, position, missing_required_annotations)
 
-        self._handle_relation(tokens)
-        return tokens
+        return self._handle_relation(tokens)
 
     def handle_unqualified_relation(self, _, __, tokens: ParseResults) -> ParseResults:
         """Handle unqualified relations."""
         subject_node_dsl = self.ensure_node(tokens[SUBJECT])
         object_node_dsl = self.ensure_node(tokens[OBJECT])
-        rel = tokens[RELATION]
-        self.graph.add_unqualified_edge(subject_node_dsl, object_node_dsl, rel)
+        relation = tokens[RELATION]
+        self.graph.add_unqualified_edge(subject_node_dsl, object_node_dsl, relation)
         return tokens
 
-    def handle_label_relation(self, line: str, position: int, tokens: ParseResults) -> ParseResults:
-        """Handle statements like ``p(X) label "Label for X"``.
-
-        :raises: RelabelWarning
-        """
-        subject_node_dsl = self.ensure_node(tokens[SUBJECT])
-        description = tokens[OBJECT]
-
-        if self.graph.has_node_description(subject_node_dsl):
-            raise RelabelWarning(
-                line_number=self.get_line_number(),
-                line=line,
-                position=position,
-                node=self.graph.node,
-                old_label=self.graph.get_node_description(subject_node_dsl),
-                new_label=description
-            )
-
-        self.graph.set_node_description(subject_node_dsl, description)
+    def handle_inverse_unqualified_relation(self, _, __, tokens: ParseResults) -> ParseResults:
+        """Handle unqualified relations that should go reverse."""
+        u = self.ensure_node(tokens[SUBJECT])
+        v = self.ensure_node(tokens[OBJECT])
+        relation = tokens[RELATION]
+        self.graph.add_unqualified_edge(v, u, relation)
         return tokens
 
     def ensure_node(self, tokens: ParseResults) -> BaseEntity:
@@ -848,15 +876,15 @@ def handle_activity_legacy(_: str, __: int, tokens: ParseResults) -> ParseResult
     tokens[MODIFIER] = ACTIVITY
     tokens[EFFECT] = {
         NAME: legacy_cls,
-        NAMESPACE: BEL_DEFAULT_NAMESPACE
+        NAMESPACE: BEL_DEFAULT_NAMESPACE,
     }
-    log.log(5, 'upgraded legacy activity to %s', legacy_cls)
+    logger.log(5, 'upgraded legacy activity to %s', legacy_cls)
     return tokens
 
 
 def handle_legacy_tloc(line: str, position: int, tokens: ParseResults) -> ParseResults:
     """Handle translocations that lack the ``fromLoc`` and ``toLoc`` entries."""
-    log.log(5, 'legacy translocation statement: %s [%d]', line, position)
+    logger.log(5, 'legacy translocation statement: %s [%d]', line, position)
     return tokens
 
 
