@@ -2,11 +2,11 @@
 
 """Functions for building node predicates."""
 
-from typing import Any, Callable, Iterable
+from typing import Any, Callable, Iterable, List, Union
 
 from .typing import NodePredicate
 from ..graph import BELGraph
-from ...constants import NAME, NAMESPACE
+from ...constants import CONCEPT, NAME, NAMESPACE
 from ...dsl import BaseEntity
 from ...typing import Strings
 
@@ -72,42 +72,68 @@ def data_missing_key_builder(key: str) -> NodePredicate:  # noqa: D202
     return data_does_not_contain_key
 
 
-def build_node_data_search(key: str, data_predicate: Callable[[Any], bool]) -> NodePredicate:  # noqa: D202
+def build_node_data_search(
+    key: Union[str, List[str]],
+    data_predicate: Callable[[Any], bool],
+) -> NodePredicate:  # noqa: D202
     """Build a filter for nodes whose associated data with the given key passes the given predicate.
 
     :param key: The node data dictionary key to check
     :param data_predicate: The filter to apply to the node data dictionary
     """
+    if isinstance(key, list):
+        _getter = _get_multi_value
+    else:
+        _getter = _get_single_value
 
     def node_data_filter(_: BELGraph, node: BaseEntity) -> bool:
         """Pass if the given node has a given data annotated and passes the contained filter."""
-        value = node.get(key)
+        value = _getter(node, key)
         return value is not None and data_predicate(value)
 
     return node_data_filter
 
 
-def build_node_graph_data_search(key: str, data_predicate: Callable[[Any], bool]):  # noqa: D202
+def build_node_graph_data_search(
+    key: Union[str, List[str]],
+    data_predicate: Callable[[Any], bool],
+):  # noqa: D202
     """Build a function for testing data associated with the node in the graph.
 
     :param key: The node data dictionary key to check
     :param data_predicate: The filter to apply to the node data dictionary
     """
+    if isinstance(key, tuple):
+        _getter = _get_multi_value
+    else:
+        _getter = _get_single_value
 
     def node_data_filter(graph: BELGraph, node: BaseEntity) -> bool:
         """Pass if the given node has a given data annotated and passes the contained filter."""
-        value = graph.nodes[node].get(key)
+        value = _getter(graph.nodes[node], key)
         return value is not None and data_predicate(value)
 
     return node_data_filter
 
 
-def build_node_key_search(query, key) -> NodePredicate:
+def _get_multi_value(d, keys):
+    value = d.get(keys[0])
+    for key in keys[1:]:
+        if value is None:
+            return
+        value = value.get(key)
+    return value
+
+
+def _get_single_value(d, key):
+    return d.get(key)
+
+
+def build_node_key_search(query: Strings, key: Union[str, List[str]]) -> NodePredicate:
     """Build a node filter for nodes whose values for the given key are superstrings of the query string(s).
 
     :param query: The query string or strings to check if they're in the node name
-    :type query: str or iter[str]
-    :param str key: The key for the node data dictionary. Should refer only to entries that have str values
+    :param key: The key for the node data dictionary. Should refer only to entries that have str values
     """
     if isinstance(query, str):
         return build_node_data_search(key, lambda s: query.lower() in s.lower())
@@ -125,7 +151,7 @@ def build_node_name_search(query: Strings) -> NodePredicate:
 
     :param query: The query string or strings to check if they're in the node name
     """
-    return build_node_key_search(query=query, key=NAME)
+    return build_node_key_search(query=query, key=[CONCEPT, NAME])
 
 
 def namespace_inclusion_builder(namespace: Strings) -> NodePredicate:
@@ -133,14 +159,14 @@ def namespace_inclusion_builder(namespace: Strings) -> NodePredicate:
     if isinstance(namespace, str):
         def namespace_filter(_: BELGraph, node: BaseEntity) -> bool:
             """Pass only for a node that has the enclosed namespace."""
-            return NAMESPACE in node and node[NAMESPACE] == namespace
+            return CONCEPT in node and node[CONCEPT][NAMESPACE] == namespace
 
     elif isinstance(namespace, Iterable):
         namespaces = set(namespace)
 
         def namespace_filter(_: BELGraph, node: BaseEntity) -> bool:
             """Pass only for a node that has a namespace in the enclosed set."""
-            return NAMESPACE in node and node[NAMESPACE] in namespaces
+            return CONCEPT in node and node[CONCEPT][NAMESPACE] in namespaces
 
     else:
         raise TypeError('Invalid type for argument: {}'.format(namespace))
