@@ -14,13 +14,13 @@ from .transfer import *
 from .utils import *
 
 __all__ = (
-    collapse.__all__ +
-    deletion.__all__ +
-    expansion.__all__ +
-    induction.__all__ +
-    induction_expansion.__all__ +
-    inference.__all__ +
-    metadata.__all__ +
-    transfer.__all__ +
-    utils.__all__
+    collapse.__all__
+    + deletion.__all__
+    + expansion.__all__
+    + induction.__all__
+    + induction_expansion.__all__
+    + inference.__all__
+    + metadata.__all__
+    + transfer.__all__
+    + utils.__all__
 )
