@@ -2,41 +2,36 @@
 
 """Functions for deleting proteins and genes that are leaves."""
 
+from typing import Iterable
+
 from ...filters.node_selection import get_nodes_by_function
-from ...pipeline.decorators import in_place_transformation, register_deprecated
+from ...pipeline.decorators import in_place_transformation
 from ....constants import GENE, RELATION, RNA, TRANSCRIBED_TO, TRANSLATED_TO
+from ....dsl import BaseEntity
 
 __all__ = [
     'prune_protein_rna_origins',
 ]
 
 
-def get_gene_leaves(graph):
+def get_gene_leaves(graph) -> Iterable[BaseEntity]:
     """Iterate over all genes who have only one connection, that's a transcription to its RNA.
 
     :param pybel.BELGraph graph: A BEL graph
-    :rtype: iter[tuple]
     """
-    for node in get_nodes_by_function(graph, GENE):
-        if graph.in_degree(node) != 0:
-            continue
-
-        if graph.out_degree(node) != 1:
-            continue
-
-        _, _, d = list(graph.out_edges(node, data=True))[0]
-
-        if d[RELATION] == TRANSCRIBED_TO:
-            yield node
+    yield from _iterate_leaves(graph, GENE, TRANSCRIBED_TO)
 
 
-def get_rna_leaves(graph):
+def get_rna_leaves(graph) -> Iterable[BaseEntity]:
     """Iterate over all RNAs who have only one connection, that's a translation to its protein.
 
     :param pybel.BELGraph graph: A BEL graph
-    :rtype: iter[tuple]
     """
-    for node in get_nodes_by_function(graph, RNA):
+    yield from _iterate_leaves(graph, RNA, TRANSLATED_TO)
+
+
+def _iterate_leaves(graph, func, relation):
+    for node in get_nodes_by_function(graph, func):
         if graph.in_degree(node) != 0:
             continue
 
@@ -45,7 +40,7 @@ def get_rna_leaves(graph):
 
         _, _, d = list(graph.out_edges(node, data=True))[0]
 
-        if d[RELATION] == TRANSLATED_TO:
+        if d[RELATION] == relation:
             yield node
 
 
@@ -69,7 +64,6 @@ def prune_protein_origins(graph):
     graph.remove_nodes_from(rna_leaves)
 
 
-@register_deprecated('prune_central_dogma')
 @in_place_transformation
 def prune_protein_rna_origins(graph):
     """Delete genes that are only connected to one node, their correspond RNA, by a translation edge.
