@@ -22,7 +22,10 @@ def update_metadata(source, target) -> None:
     target.annotation_url.update(source.annotation_url)
     target.annotation_pattern.update(source.annotation_pattern)
     for keyword, values in source.annotation_list.items():
-        target.annotation_list[keyword].update(values)
+        if keyword not in target.annotation_list:
+            target.annotation_list[keyword] = values
+        else:
+            target.annotation_list[keyword].update(values)
 
 
 def update_node_helper(source: nx.Graph, target: nx.Graph) -> None:
