@@ -11,20 +11,21 @@ from io import BytesIO, StringIO
 from pathlib import Path
 
 from pybel import (
-    BELGraph, from_bytes, from_json, from_json_file, from_jsons, from_lines, from_path, from_pickle, from_url,
-    to_bel_lines, to_bytes, to_csv, to_graphml, to_gsea, to_json, to_json_file, to_jsons, to_pickle, to_sif,
+    BELGraph, from_bel_script, from_bel_script_url, from_bytes, from_nodelink, from_nodelink_file, from_pickle,
+    to_bel_script_lines, to_bytes, to_csv, to_graphml, to_gsea, to_nodelink, to_nodelink_file, to_pickle, to_sif,
 )
+from pybel.config import PYBEL_MINIMUM_IMPORT_VERSION
 from pybel.constants import (
-    ANNOTATIONS, CITATION, DECREASES, DIRECTLY_DECREASES, EVIDENCE, GRAPH_PYBEL_VERSION, INCREASES,
-    PYBEL_MINIMUM_IMPORT_VERSION, RELATION,
+    ANNOTATIONS, CITATION, DECREASES, DIRECTLY_DECREASES, EVIDENCE, GRAPH_PYBEL_VERSION, INCREASES, RELATION,
 )
-from pybel.dsl import BaseEntity, gene
-from pybel.examples import sialic_acid_graph
+from pybel.dsl import BaseEntity, Gene, Protein
+from pybel.examples.sialic_acid_example import sialic_acid_graph
 from pybel.io.exc import ImportVersionWarning, import_version_message_fmt
+from pybel.io.line_utils import parse_lines
+from pybel.io.nodelink import from_nodelink_jsons, to_nodelink_jsons
 from pybel.parser import BELParser
 from pybel.parser.exc import (
-    BELSyntaxError, InvalidFunctionSemantic, MissingCitationException,
-    MissingNamespaceRegexWarning,
+    BELSyntaxError, InvalidFunctionSemantic, MissingCitationException, MissingNamespaceRegexWarning,
 )
 from pybel.struct.summary import get_syntax_errors
 from pybel.testing.cases import TemporaryCacheClsMixin
@@ -38,7 +39,7 @@ from tests.constants import (
 )
 
 logging.getLogger('requests').setLevel(logging.WARNING)
-log = logging.getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 testan1 = '1'
 
@@ -46,22 +47,26 @@ testan1 = '1'
 class TestExampleInterchange(unittest.TestCase):
     """Test round-trip interchange of the sialic acid graph example."""
 
-    def help_test_equal(self, graph):
-        """Check that a graph is equal to the sialic acid graph example.
-
-        :type graph: pybel.BELGraph
-        """
+    def _help_test_equal(self, graph: BELGraph):
+        """Check that a graph is equal to the sialic acid graph example."""
         for node in graph:
             self.assertIsInstance(node, BaseEntity)
 
         self.assertEqual(set(sialic_acid_graph), set(graph))
         self.assertEqual(set(sialic_acid_graph.edges()), set(graph.edges()))
 
+        for node in sialic_acid_graph:
+            if not isinstance(node, Protein):
+                continue
+            if node.namespace == 'HGNC' and node.name == 'CD33' and not node.variants:
+                self.assertIsNotNone(node.xrefs)
+                self.assertEqual(1, len(node.xrefs))
+
     def test_example_bytes(self):
         """Test the round-trip through bytes."""
         graph_bytes = to_bytes(sialic_acid_graph)
         graph = from_bytes(graph_bytes)
-        self.help_test_equal(graph)
+        self._help_test_equal(graph)
 
     def test_example_pickle(self):
         """Test the round-trip through a pickle."""
@@ -69,41 +74,46 @@ class TestExampleInterchange(unittest.TestCase):
         to_pickle(sialic_acid_graph, bio)
         bio.seek(0)
         graph = from_pickle(bio)
-        self.help_test_equal(graph)
+        self._help_test_equal(graph)
 
     def test_thorough_json(self):
         """Test the round-trip through node-link JSON."""
-        graph_json_dict = to_json(sialic_acid_graph)
-        graph = from_json(graph_json_dict)
-        self.help_test_equal(graph)
+        graph_json_dict = to_nodelink(sialic_acid_graph)
+        graph = from_nodelink(graph_json_dict)
+        self._help_test_equal(graph)
 
     def test_thorough_jsons(self):
         """Test the round-trip through a node-link JSON string."""
-        graph_json_str = to_jsons(sialic_acid_graph)
-        graph = from_jsons(graph_json_str)
-        self.help_test_equal(graph)
+        graph_json_str = to_nodelink_jsons(sialic_acid_graph)
+        graph = from_nodelink_jsons(graph_json_str)
+        self._help_test_equal(graph)
 
     def test_thorough_json_file(self):
         """Test the round-trip through a node-link JSON file."""
         sio = StringIO()
-        to_json_file(sialic_acid_graph, sio)
+        to_nodelink_file(sialic_acid_graph, sio)
         sio.seek(0)
-        graph = from_json_file(sio)
-        self.help_test_equal(graph)
+        graph = from_nodelink_file(sio)
+        self._help_test_equal(graph)
 
 
 class TestInterchange(TemporaryCacheClsMixin, BelReconstitutionMixin):
     @classmethod
     def setUpClass(cls):
         """Set up this class with several pre-loaded BEL graphs."""
-        super(TestInterchange, cls).setUpClass()
+        super().setUpClass()
 
         with mock_bel_resources:
-            cls.thorough_graph = from_path(test_bel_thorough, manager=cls.manager, allow_nested=True)
-            cls.slushy_graph = from_path(test_bel_slushy, manager=cls.manager, disallow_unqualified_translocations=True)
-            cls.simple_graph = from_url(Path(test_bel_simple).as_uri(), manager=cls.manager)
-            cls.isolated_graph = from_path(test_bel_isolated, manager=cls.manager)
-            cls.misordered_graph = from_path(test_bel_misordered, manager=cls.manager, citation_clearing=False)
+            cls.thorough_graph = from_bel_script(test_bel_thorough, manager=cls.manager, disallow_nested=False)
+            cls.slushy_graph = from_bel_script(
+                test_bel_slushy,
+                manager=cls.manager,
+                disallow_unqualified_translocations=True,
+                disallow_nested=True,
+            )
+            cls.simple_graph = from_bel_script_url(Path(test_bel_simple).as_uri(), manager=cls.manager)
+            cls.isolated_graph = from_bel_script(test_bel_isolated, manager=cls.manager)
+            cls.misordered_graph = from_bel_script(test_bel_misordered, manager=cls.manager, citation_clearing=False)
 
     def test_thorough_path(self):
         self.bel_thorough_reconstituted(self.thorough_graph)
@@ -121,20 +131,20 @@ class TestInterchange(TemporaryCacheClsMixin, BelReconstitutionMixin):
         self.bel_thorough_reconstituted(graph)
 
     def test_thorough_json(self):
-        graph_json_dict = to_json(self.thorough_graph)
-        graph = from_json(graph_json_dict)
+        graph_json_dict = to_nodelink(self.thorough_graph)
+        graph = from_nodelink(graph_json_dict)
         self.bel_thorough_reconstituted(graph)
 
     def test_thorough_jsons(self):
-        graph_json_str = to_jsons(self.thorough_graph)
-        graph = from_jsons(graph_json_str)
+        graph_json_str = to_nodelink_jsons(self.thorough_graph)
+        graph = from_nodelink_jsons(graph_json_str)
         self.bel_thorough_reconstituted(graph)
 
     def test_thorough_json_file(self):
         sio = StringIO()
-        to_json_file(self.thorough_graph, sio)
+        to_nodelink_file(self.thorough_graph, sio)
         sio.seek(0)
-        graph = from_json_file(sio)
+        graph = from_nodelink_file(sio)
         self.bel_thorough_reconstituted(graph)
 
     def test_thorough_graphml(self):
@@ -174,8 +184,9 @@ class TestInterchange(TemporaryCacheClsMixin, BelReconstitutionMixin):
         os.remove(path)
 
     def test_thorough_upgrade(self):
-        lines = to_bel_lines(self.thorough_graph)
-        reconstituted = from_lines(lines, manager=self.manager)
+        lines = to_bel_script_lines(self.thorough_graph)
+        reconstituted = BELGraph()
+        parse_lines(reconstituted, lines, manager=self.manager)
         self.bel_thorough_reconstituted(reconstituted, check_citation_name=False, check_path=False)
 
     def test_slushy(self):
@@ -195,16 +206,13 @@ class TestInterchange(TemporaryCacheClsMixin, BelReconstitutionMixin):
         self.assertEqual(98, first_exc.line_number)
 
     def test_slushy_json(self):
-        graph_json = to_json(self.slushy_graph)
-        graph = from_json(graph_json)
+        graph_json = to_nodelink(self.slushy_graph)
+        graph = from_nodelink(graph_json)
         self.bel_slushy_reconstituted(graph)
 
     def test_slushy_graphml(self):
         handle, path = tempfile.mkstemp()
-
-        with open(path, 'wb') as f:
-            to_graphml(self.slushy_graph, f)
-
+        to_graphml(self.slushy_graph, path)
         os.close(handle)
         os.remove(path)
 
@@ -215,10 +223,11 @@ class TestInterchange(TemporaryCacheClsMixin, BelReconstitutionMixin):
         self.bel_isolated_reconstituted(self.isolated_graph)
 
     def test_isolated_upgrade(self):
-        lines = to_bel_lines(self.isolated_graph)
+        lines = to_bel_script_lines(self.isolated_graph)
 
         with mock_bel_resources:
-            reconstituted = from_lines(lines, manager=self.manager)
+            reconstituted = BELGraph()
+            parse_lines(graph=reconstituted, lines=lines, manager=self.manager)
 
         self.bel_isolated_reconstituted(reconstituted)
 
@@ -252,23 +261,23 @@ class TestInterchange(TemporaryCacheClsMixin, BelReconstitutionMixin):
             CITATION: citation_1,
             EVIDENCE: evidence_1,
             ANNOTATIONS: {
-                'TESTAN1': {testan1: True}
-            }
+                'TESTAN1': {testan1: True},
+            },
         }
         self.assert_has_edge(self.misordered_graph, egfr, casp8, **e3)
 
 
 namespace_to_term = {
     'TESTNS': {
-        "1": "GRP",
-        "2": "GRP"
+        (None, "1"): "GRP",
+        (None, "2"): "GRP",
     }
 }
 
 annotation_to_term = {
     'TestAnnotation1': {'A', 'B', 'C'},
     'TestAnnotation2': {'X', 'Y', 'Z'},
-    'TestAnnotation3': {'D', 'E', 'F'}
+    'TestAnnotation3': {'D', 'E', 'F'},
 }
 
 
@@ -278,25 +287,28 @@ class TestFull(TestTokenParserBase):
         cls.graph = BELGraph()
         cls.parser = BELParser(
             cls.graph,
-            namespace_to_term=namespace_to_term,
+            namespace_to_term_to_encoding=namespace_to_term,
             annotation_to_term=annotation_to_term,
-            namespace_to_pattern={'dbSNP': re.compile('rs[0-9]*')}
+            namespace_to_pattern={'dbSNP': re.compile('rs[0-9]*')},
         )
 
     def test_regex_match(self):
         line = 'g(dbSNP:rs10234) -- g(dbSNP:rs10235)'
         self.add_default_provenance()
         self.parser.parseString(line)
-        self.assertIn(gene('dbSNP', 'rs10234'), self.parser.graph)
-        self.assertIn(gene('dbSNP', 'rs10235'), self.parser.graph)
+        self.assertIn(Gene('dbSNP', 'rs10234'), self.parser.graph)
+        self.assertIn(Gene('dbSNP', 'rs10235'), self.parser.graph)
 
     def test_regex_mismatch(self):
-        line = 'g(dbSNP:10234) -- g(dbSNP:rr10235)'
-
+        statement = 'g(dbSNP:10234) -- g(dbSNP:rr10235)'
         with self.assertRaises(MissingNamespaceRegexWarning):
-            self.parser.parseString(line)
+            self.parser.parseString(statement)
 
     def test_semantic_failure(self):
+        self.assertIsNotNone(self.parser.concept_parser.namespace_to_name_to_encoding)
+        self.assertIn('TESTNS', self.parser.concept_parser.namespace_to_name_to_encoding)
+        self.assertIn('1', self.parser.concept_parser.namespace_to_name_to_encoding['TESTNS'])
+        self.assertIn('2', self.parser.concept_parser.namespace_to_name_to_encoding['TESTNS'])
         statement = "bp(TESTNS:1) -- p(TESTNS:2)"
         with self.assertRaises(InvalidFunctionSemantic):
             self.parser.parseString(statement)
@@ -306,7 +318,7 @@ class TestFull(TestTokenParserBase):
             test_set_evidence,
             'SET TestAnnotation1 = "A"',
             'SET TestAnnotation2 = "X"',
-            'g(TESTNS:1) -> g(TESTNS:2)'
+            'g(TESTNS:1) -> g(TESTNS:2)',
         ]
 
         with self.assertRaises(MissingCitationException):
@@ -323,8 +335,8 @@ class TestFull(TestTokenParserBase):
 
         self.parser.parse_lines(statements)
 
-        test_node_1 = gene(namespace='TESTNS', name='1')
-        test_node_2 = gene(namespace='TESTNS', name='2')
+        test_node_1 = Gene(namespace='TESTNS', name='1')
+        test_node_2 = Gene(namespace='TESTNS', name='2')
 
         self.assertEqual(2, self.graph.number_of_nodes())
         self.assertIn(test_node_1, self.graph)
@@ -352,8 +364,8 @@ class TestFull(TestTokenParserBase):
         ]
         self.parser.parse_lines(statements)
 
-        test_node_1_dict = gene(namespace='TESTNS', name='1')
-        test_node_2_dict = gene(namespace='TESTNS', name='2')
+        test_node_1_dict = Gene(namespace='TESTNS', name='1')
+        test_node_2_dict = Gene(namespace='TESTNS', name='2')
 
         self.assertEqual(2, self.parser.graph.number_of_nodes())
         self.assertIn(test_node_1_dict, self.graph)
@@ -381,8 +393,8 @@ class TestFull(TestTokenParserBase):
         ]
         self.parser.parse_lines(statements)
 
-        test_node_1_dict = gene(namespace='TESTNS', name='1')
-        test_node_2_dict = gene(namespace='TESTNS', name='2')
+        test_node_1_dict = Gene(namespace='TESTNS', name='1')
+        test_node_2_dict = Gene(namespace='TESTNS', name='2')
 
         self.assertEqual(2, self.parser.graph.number_of_nodes())
         self.assertIn(test_node_1_dict, self.graph)
