@@ -6,17 +6,18 @@ import logging
 import unittest
 
 from pybel.constants import (
-    BEL_DEFAULT_NAMESPACE, FRAGMENT, FRAGMENT_DESCRIPTION, FRAGMENT_MISSING, FRAGMENT_START, FRAGMENT_STOP,
-    FUSION_MISSING, FUSION_REFERENCE, FUSION_START, FUSION_STOP, GMOD, IDENTIFIER, KIND, LOCATION, NAME, NAMESPACE,
+    BEL_DEFAULT_NAMESPACE, CONCEPT, FRAGMENT, FRAGMENT_DESCRIPTION, FRAGMENT_MISSING, FRAGMENT_START, FRAGMENT_STOP,
+    FUSION_MISSING, FUSION_REFERENCE, FUSION_START, FUSION_STOP, GMOD, KIND, LOCATION, NAME, NAMESPACE,
     PARTNER_3P, PARTNER_5P, PMOD, PMOD_CODE, PMOD_POSITION, RANGE_3P, RANGE_5P,
 )
-from pybel.dsl import entity, gmod, hgvs, pmod
+from pybel.dsl import GeneModification, Hgvs, ProteinModification
+from pybel.language import Entity
+from pybel.parser import ConceptParser
 from pybel.parser.modifiers import (
     get_fragment_language, get_fusion_language, get_gene_modification_language, get_gene_substitution_language,
     get_hgvs_language, get_location_language, get_protein_modification_language, get_protein_substitution_language,
     get_truncation_language,
 )
-from pybel.parser.parse_identifier import IdentifierParser
 
 log = logging.getLogger(__name__)
 
@@ -27,74 +28,74 @@ class TestHGVSParser(unittest.TestCase):
 
     def test_protein_del(self):
         statement = 'variant(p.Phe508del)'
-        expected = hgvs('p.Phe508del')
+        expected = Hgvs('p.Phe508del')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_protein_del_quoted(self):
         statement = 'variant("p.Phe508del")'
-        expected = hgvs('p.Phe508del')
+        expected = Hgvs('p.Phe508del')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_protein_mut(self):
         statement = 'var(p.Gly576Ala)'
-        expected = hgvs('p.Gly576Ala')
+        expected = Hgvs('p.Gly576Ala')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_unspecified(self):
         statement = 'var(=)'
-        expected = hgvs('=')
+        expected = Hgvs('=')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_frameshift(self):
         statement = 'variant(p.Thr1220Lysfs)'
-        expected = hgvs('p.Thr1220Lysfs')
+        expected = Hgvs('p.Thr1220Lysfs')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_snp(self):
         statement = 'var(c.1521_1523delCTT)'
-        expected = hgvs('c.1521_1523delCTT')
+        expected = Hgvs('c.1521_1523delCTT')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_chromosome_1(self):
         statement = 'variant(g.117199646_117199648delCTT)'
-        expected = hgvs('g.117199646_117199648delCTT')
+        expected = Hgvs('g.117199646_117199648delCTT')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_chromosome_2(self):
         statement = 'var(c.1521_1523delCTT)'
-        expected = hgvs('c.1521_1523delCTT')
+        expected = Hgvs('c.1521_1523delCTT')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_rna_del(self):
         statement = 'var(r.1653_1655delcuu)'
-        expected = hgvs('r.1653_1655delcuu')
+        expected = Hgvs('r.1653_1655delcuu')
         result = self.parser.parseString(statement)
         self.assertEqual(expected, result.asDict())
 
     def test_protein_trunc_triple(self):
         statement = 'var(p.Cys65*)'
         result = self.parser.parseString(statement)
-        expected = hgvs('p.Cys65*')
+        expected = Hgvs('p.Cys65*')
         self.assertEqual(expected, result.asDict())
 
     def test_protein_trunc_legacy(self):
         statement = 'var(p.65*)'
         result = self.parser.parseString(statement)
-        expected = hgvs('p.65*')
+        expected = Hgvs('p.65*')
         self.assertEqual(expected, result.asDict())
 
 
 class TestPmod(unittest.TestCase):
     def setUp(self):
-        identifier_parser = IdentifierParser()
+        identifier_parser = ConceptParser()
         identifier_qualified = identifier_parser.identifier_qualified
         self.parser = get_protein_modification_language(identifier_qualified)
 
@@ -103,12 +104,12 @@ class TestPmod(unittest.TestCase):
 
         expected = {
             KIND: PMOD,
-            IDENTIFIER: {
+            CONCEPT: {
                 NAMESPACE: BEL_DEFAULT_NAMESPACE,
                 NAME: 'Ph',
             },
         }
-        self.assertEqual(expected, pmod('Ph'))
+        self.assertEqual(expected, ProteinModification('Ph'))
         self.assertEqual(expected, result.asDict())
 
     def test_bel_name(self):
@@ -131,13 +132,13 @@ class TestPmod(unittest.TestCase):
 
         expected = {
             KIND: PMOD,
-            IDENTIFIER: {
+            CONCEPT: {
                 NAMESPACE: BEL_DEFAULT_NAMESPACE,
                 NAME: 'Ph',
             },
             PMOD_CODE: 'Ser',
         }
-        self.assertEqual(expected, pmod('Ph', code='Ser'))
+        self.assertEqual(expected, ProteinModification('Ph', code='Ser'))
         self.assertEqual(expected, result.asDict())
 
     def test_residue(self):
@@ -151,15 +152,15 @@ class TestPmod(unittest.TestCase):
 
         expected = {
             KIND: PMOD,
-            IDENTIFIER: {
+            CONCEPT: {
                 NAMESPACE: BEL_DEFAULT_NAMESPACE,
                 NAME: 'Ph',
             },
             PMOD_CODE: 'Ser',
-            PMOD_POSITION: 473
+            PMOD_POSITION: 473,
         }
 
-        self.assertEqual(expected, pmod('Ph', code='Ser', position=473))
+        self.assertEqual(expected, ProteinModification('Ph', code='Ser', position=473))
         self.assertEqual(expected, result.asDict())
 
     def test_full(self):
@@ -181,45 +182,45 @@ class TestPmod(unittest.TestCase):
 
         expected = {
             KIND: PMOD,
-            IDENTIFIER: entity('MOD', 'PhosRes'),
+            CONCEPT: Entity(namespace='MOD', name='PhosRes'),
             PMOD_CODE: 'Ser',
-            PMOD_POSITION: 473
+            PMOD_POSITION: 473,
         }
 
-        self.assertEqual(expected, pmod(name='PhosRes', namespace='MOD', code='Ser', position=473))
+        self.assertEqual(expected, ProteinModification(name='PhosRes', namespace='MOD', code='Ser', position=473))
         self.assertEqual(expected, result.asDict())
 
     def test_full_with_non_standard_namespace(self):
         self._help_test_non_standard_namespace('proteinModification(MOD:PhosRes, S, 473)')
         self._help_test_non_standard_namespace('proteinModification(MOD:PhosRes, Ser, 473)')
-        self._help_test_non_standard_namespace('pmod(MOD:PhosRes, S, 473)')
-        self._help_test_non_standard_namespace('pmod(MOD:PhosRes, Ser, 473)')
+        self._help_test_non_standard_namespace('proteinModification(MOD:PhosRes, S, 473)')
+        self._help_test_non_standard_namespace('proteinModification(MOD:PhosRes, Ser, 473)')
 
 
 class TestGeneModification(unittest.TestCase):
     def setUp(self):
-        identifier_parser = IdentifierParser()
+        identifier_parser = ConceptParser()
         identifier_qualified = identifier_parser.identifier_qualified
         self.parser = get_gene_modification_language(identifier_qualified)
 
-        self.expected = gmod('Me')
+        self.expected = GeneModification('Me')
 
     def test_dsl(self):
         self.assertEqual({
             KIND: GMOD,
-            IDENTIFIER: {
+            CONCEPT: {
                 NAME: 'Me',
-                NAMESPACE: BEL_DEFAULT_NAMESPACE
+                NAMESPACE: BEL_DEFAULT_NAMESPACE,
             }
         }, self.expected)
 
     def test_gmod_short(self):
-        statement = 'gmod(M)'
+        statement = 'geneModification(M)'
         result = self.parser.parseString(statement)
         self.assertEqual(self.expected, result.asDict())
 
     def test_gmod_unabbreviated(self):
-        statement = 'gmod(Me)'
+        statement = 'geneModification(Me)'
         result = self.parser.parseString(statement)
         self.assertEqual(self.expected, result.asDict())
 
@@ -237,14 +238,14 @@ class TestProteinSubstitution(unittest.TestCase):
         statement = 'sub(A, 127, Y)'
         result = self.parser.parseString(statement)
 
-        expected_list = hgvs('p.Ala127Tyr')
+        expected_list = Hgvs('p.Ala127Tyr')
         self.assertEqual(expected_list, result.asDict())
 
     def test_psub_2(self):
         statement = 'sub(Ala, 127, Tyr)'
         result = self.parser.parseString(statement)
 
-        expected_list = hgvs('p.Ala127Tyr')
+        expected_list = Hgvs('p.Ala127Tyr')
         self.assertEqual(expected_list, result.asDict())
 
 
@@ -256,7 +257,7 @@ class TestGeneSubstitutionParser(unittest.TestCase):
         statement = 'sub(G,308,A)'
         result = self.parser.parseString(statement)
 
-        expected_dict = hgvs('c.308G>A')
+        expected_dict = Hgvs('c.308G>A')
         self.assertEqual(expected_dict, result.asDict())
 
 
@@ -266,7 +267,7 @@ class TestFragmentParser(unittest.TestCase):
     def setUp(self):
         self.parser = get_fragment_language()
 
-    def help_test_known_length(self, s):
+    def _help_test_known_length(self, s):
         result = self.parser.parseString(s)
         expected = {
             KIND: FRAGMENT,
@@ -278,14 +279,14 @@ class TestFragmentParser(unittest.TestCase):
     def test_known_length_unquoted(self):
         """test known length"""
         s = 'frag(5_20)'
-        self.help_test_known_length(s)
+        self._help_test_known_length(s)
 
     def test_known_length_quotes(self):
         """test known length"""
         s = 'frag("5_20")'
-        self.help_test_known_length(s)
+        self._help_test_known_length(s)
 
-    def help_test_unknown_length(self, s):
+    def _help_test_unknown_length(self, s):
         result = self.parser.parseString(s)
         expected = {
             KIND: FRAGMENT,
@@ -297,14 +298,14 @@ class TestFragmentParser(unittest.TestCase):
     def test_unknown_length_unquoted(self):
         """amino-terminal fragment of unknown length"""
         s = 'frag(1_?)'
-        self.help_test_unknown_length(s)
+        self._help_test_unknown_length(s)
 
     def test_unknown_length_quoted(self):
         """amino-terminal fragment of unknown length"""
         s = 'frag("1_?")'
-        self.help_test_unknown_length(s)
+        self._help_test_unknown_length(s)
 
-    def help_test_unknown_start_stop(self, s):
+    def _help_test_unknown_start_stop(self, s):
         result = self.parser.parseString(s)
         expected = {
             KIND: FRAGMENT,
@@ -316,14 +317,14 @@ class TestFragmentParser(unittest.TestCase):
     def test_unknown_start_stop_unquoted(self):
         """fragment with unknown start/stop"""
         s = 'frag(?_*)'
-        self.help_test_unknown_start_stop(s)
+        self._help_test_unknown_start_stop(s)
 
     def test_unknown_start_stop_quoted(self):
         """fragment with unknown start/stop"""
         s = 'frag("?_*")'
-        self.help_test_unknown_start_stop(s)
+        self._help_test_unknown_start_stop(s)
 
-    def help_test_descriptor(self, s):
+    def _help_test_descriptor(self, s):
         result = self.parser.parseString(s)
         expected = {
             KIND: FRAGMENT,
@@ -335,12 +336,12 @@ class TestFragmentParser(unittest.TestCase):
     def test_descriptor_unquoted(self):
         """fragment with unknown start/stop and a descriptor"""
         s = 'frag(?, "55kD")'
-        self.help_test_descriptor(s)
+        self._help_test_descriptor(s)
 
     def test_descriptor_quoted(self):
         """fragment with unknown start/stop and a descriptor"""
         s = 'frag("?", "55kD")'
-        self.help_test_descriptor(s)
+        self._help_test_descriptor(s)
 
 
 class TestTruncationParser(unittest.TestCase):
@@ -351,7 +352,7 @@ class TestTruncationParser(unittest.TestCase):
         statement = 'trunc(40)'
         result = self.parser.parseString(statement)
 
-        expected = hgvs('p.40*')
+        expected = Hgvs('p.40*')
         self.assertEqual(expected, result.asDict())
 
     def test_trunc_2(self):
@@ -359,19 +360,19 @@ class TestTruncationParser(unittest.TestCase):
         statement = 'trunc(Gly40)'
         result = self.parser.parseString(statement)
 
-        expected = hgvs('p.Gly40*')
+        expected = Hgvs('p.Gly40*')
         self.assertEqual(expected, result.asDict())
 
     def test_trunc_missing_number(self):
         """Test that an error is raised for a truncation in which the position is omitted."""
         statement = 'trunc(Gly)'
         with self.assertRaises(Exception):
-            result = self.parser.parseString(statement)
+            self.parser.parseString(statement)
 
 
 class TestFusionParser(unittest.TestCase):
     def setUp(self):
-        identifier_parser = IdentifierParser()
+        identifier_parser = ConceptParser()
         identifier_qualified = identifier_parser.identifier_qualified
         self.parser = get_fusion_language(identifier_qualified)
 
@@ -382,23 +383,26 @@ class TestFusionParser(unittest.TestCase):
 
         expected = {
             PARTNER_5P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'TMPRSS2'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'TMPRSS2',
+                },
             },
             RANGE_5P: {
                 FUSION_REFERENCE: 'r',
                 FUSION_START: 1,
                 FUSION_STOP: 79
-
             },
             PARTNER_3P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'ERG'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'ERG',
+                },
             },
             RANGE_3P: {
                 FUSION_REFERENCE: 'r',
                 FUSION_START: 312,
-                FUSION_STOP: 5034
+                FUSION_STOP: 5034,
             }
         }
 
@@ -411,16 +415,19 @@ class TestFusionParser(unittest.TestCase):
 
         expected = {
             PARTNER_5P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'TMPRSS2'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'TMPRSS2',
+                }
             },
             RANGE_5P: {
                 FUSION_MISSING: '?'
-
             },
             PARTNER_3P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'ERG'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'ERG',
+                },
             },
             RANGE_3P: {
                 FUSION_MISSING: '?'
@@ -436,8 +443,10 @@ class TestFusionParser(unittest.TestCase):
 
         expected = {
             PARTNER_5P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'TMPRSS2'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'TMPRSS2',
+                },
             },
             RANGE_5P: {
                 FUSION_REFERENCE: 'r',
@@ -446,8 +455,10 @@ class TestFusionParser(unittest.TestCase):
 
             },
             PARTNER_3P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'ERG'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'ERG',
+                },
             },
             RANGE_3P: {
                 FUSION_REFERENCE: 'r',
@@ -465,8 +476,10 @@ class TestFusionParser(unittest.TestCase):
 
         expected = {
             PARTNER_5P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'TMPRSS2'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'TMPRSS2',
+                },
             },
             RANGE_5P: {
                 FUSION_REFERENCE: 'r',
@@ -475,8 +488,10 @@ class TestFusionParser(unittest.TestCase):
 
             },
             PARTNER_3P: {
-                NAMESPACE: 'HGNC',
-                NAME: 'ERG'
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'ERG',
+                },
             },
             RANGE_3P: {
                 FUSION_REFERENCE: 'r',
@@ -490,14 +505,14 @@ class TestFusionParser(unittest.TestCase):
 
 class TestLocation(unittest.TestCase):
     def setUp(self):
-        identifier_parser = IdentifierParser()
+        identifier_parser = ConceptParser()
         identifier_qualified = identifier_parser.identifier_qualified
         self.parser = get_location_language(identifier_qualified)
 
     def test_a(self):
-        statement = 'loc(GOCC:intracellular)'
+        statement = 'loc(GO:intracellular)'
         result = self.parser.parseString(statement)
         expected = {
-            LOCATION: {NAMESPACE: 'GOCC', NAME: 'intracellular'}
+            LOCATION: {NAMESPACE: 'GO', NAME: 'intracellular'}
         }
         self.assertEqual(expected, result.asDict())
