@@ -6,15 +6,15 @@ import unittest
 
 from pybel import BELGraph
 from pybel.constants import (
-    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSES_NO_CHANGE, CITATION, CITATION_AUTHORS,
-    CITATION_REFERENCE, CITATION_TYPE, CITATION_TYPE_ONLINE, CITATION_TYPE_PUBMED, DECREASES, DEGRADATION,
-    DIRECTLY_DECREASES, DIRECTLY_INCREASES, EVIDENCE, GMOD, INCREASES, LOCATION, MODIFIER, OBJECT, POLAR_RELATIONS,
-    POSITIVE_CORRELATION, RELATION, SUBJECT, TRANSLOCATION,
+    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSES_NO_CHANGE, CITATION, CITATION_AUTHORS, CITATION_IDENTIFIER, CITATION_DB,
+    CITATION_TYPE_ONLINE, CITATION_TYPE_PUBMED, DECREASES, DEGRADATION, DIRECTLY_DECREASES, DIRECTLY_INCREASES,
+    EVIDENCE, GMOD, INCREASES, LOCATION, MODIFIER, OBJECT, POLAR_RELATIONS, POSITIVE_CORRELATION, RELATION, SUBJECT,
+    TRANSLOCATION,
 )
 from pybel.dsl import (
-    abundance, activity, degradation, entity, fragment, gene, gmod, hgvs, pmod, protein, secretion,
-    translocation,
+    abundance, activity, degradation, fragment, gene, gmod, hgvs, pmod, protein, secretion, translocation,
 )
+from pybel.language import Entity
 from pybel.struct.filters.edge_predicate_builders import build_relation_predicate
 from pybel.struct.filters.edge_predicates import (
     edge_has_activity, edge_has_annotation, edge_has_degradation,
@@ -47,8 +47,8 @@ class TestNodePredicates(unittest.TestCase):
     def test_none(self):
         """Test permissive node predicate with graph and tuple."""
         g = BELGraph()
-        p1_tuple = g.add_node_from_data(p1)
-        self.assertTrue(keep_node_permissive(g, p1_tuple))
+        g.add_node_from_data(p1)
+        self.assertTrue(keep_node_permissive(g, p1))
 
     def test_p1_data_variants(self):
         """Test node predicates on BRAF."""
@@ -139,17 +139,15 @@ class TestNodePredicates(unittest.TestCase):
     def test_p1_active(self):
         """cat(p(HGNC:HSD11B1)) increases deg(a(CHEBI:cortisol))"""
         g = BELGraph()
-        u_node = protein(name='HSD11B1', namespace='HGNC')
-        v_node = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
-        u = g.add_node_from_data(u_node)
-        v = g.add_node_from_data(v_node)
 
-        g.add_qualified_edge(
-            u_node,
-            v_node,
-            relation=INCREASES,
+        u = protein(name='HSD11B1', namespace='HGNC')
+        v = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+
+        g.add_increases(
+            u,
+            v,
             citation={
-                CITATION_TYPE: CITATION_TYPE_ONLINE, CITATION_REFERENCE: 'https://www.ncbi.nlm.nih.gov/gene/3290'
+                CITATION_DB: CITATION_TYPE_ONLINE, CITATION_IDENTIFIER: 'https://www.ncbi.nlm.nih.gov/gene/3290'
             },
             evidence="Entrez Gene Summary: Human: The protein encoded by this gene is a microsomal enzyme that "
                      "catalyzes the conversion of the stress hormone cortisol to the inactive metabolite cortisone. "
@@ -171,24 +169,21 @@ class TestNodePredicates(unittest.TestCase):
         self.assertFalse(has_activity(g, v))
 
     def test_object_has_translocation(self):
-        """p(HGNC: EGF) increases tloc(p(HGNC: VCP), GOCCID: 0005634, GOCCID: 0005737)"""
+        """p(HGNC: EGF) increases tloc(p(HGNC: VCP), GO:0005634, GO:0005737)"""
         g = BELGraph()
-        u_node = protein(name='EFG', namespace='HGNC')
-        v_node = protein(name='VCP', namespace='HGNC')
-        u = g.add_node_from_data(u_node)
-        v = g.add_node_from_data(v_node)
+        u = protein(name='EFG', namespace='HGNC')
+        v = protein(name='VCP', namespace='HGNC')
 
-        g.add_qualified_edge(
-            u_node,
-            v_node,
-            relation=INCREASES,
+        g.add_increases(
+            u,
+            v,
             citation='10855792',
             evidence="Although found predominantly in the cytoplasm and, less abundantly, in the nucleus, VCP can be "
                      "translocated from the nucleus after stimulation with epidermal growth factor.",
             annotations={'Species': '9606'},
             object_modifier=translocation(
-                from_loc=entity(namespace='GO', identifier='0005634'),
-                to_loc=entity(namespace='GO', identifier='0005737')
+                from_loc=Entity(namespace='GO', identifier='0005634'),
+                to_loc=Entity(namespace='GO', identifier='0005737'),
             )
         )
 
@@ -207,14 +202,12 @@ class TestNodePredicates(unittest.TestCase):
     def test_object_has_secretion(self):
         """p(MGI:Il4) increases sec(p(MGI:Cxcl1))"""
         g = BELGraph()
-        u_node = protein(name='Il4', namespace='MGI')
-        v_node = protein(name='Cxcl1', namespace='MGI')
-        u = g.add_node_from_data(u_node)
-        v = g.add_node_from_data(v_node)
+        u = protein(name='Il4', namespace='MGI')
+        v = protein(name='Cxcl1', namespace='MGI')
 
         g.add_increases(
-            u_node,
-            v_node,
+            u,
+            v,
             citation='10072486',
             evidence='Compared with controls treated with culture medium alone, IL-4 and IL-5 induced significantly '
                      'higher levels of MIP-2 and KC production; IL-4 also increased the production of MCP-1 '
@@ -240,14 +233,12 @@ class TestNodePredicates(unittest.TestCase):
     def test_subject_has_secretion(self):
         """sec(p(MGI:S100b)) increases a(CHEBI:"nitric oxide")"""
         g = BELGraph()
-        u_node = protein(name='S100b', namespace='MGI')
-        v_node = abundance(name='nitric oxide', namespace='CHEBI')
-        u = g.add_node_from_data(u_node)
-        v = g.add_node_from_data(v_node)
+        u = protein(name='S100b', namespace='MGI')
+        v = abundance(name='nitric oxide', namespace='CHEBI')
 
         g.add_increases(
-            u_node,
-            v_node,
+            u,
+            v,
             citation='11180510',
             evidence='S100B protein is also secreted by astrocytes and acts on these cells to stimulate nitric oxide '
                      'secretion in an autocrine manner.',
@@ -298,9 +289,14 @@ class TestNodePredicates(unittest.TestCase):
 
     def test_node_exclusion_tuples(self):
         g = BELGraph()
-        u = g.add_node_from_data(protein(name='S100b', namespace='MGI'))
-        v = g.add_node_from_data(abundance(name='nitric oxide', namespace='CHEBI'))
-        w = g.add_node_from_data(abundance(name='cortisol', namespace='CHEBI', identifier='17650'))
+
+        u = protein(name='S100b', namespace='MGI')
+        v = abundance(name='nitric oxide', namespace='CHEBI')
+        w = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+
+        g.add_node_from_data(u)
+        g.add_node_from_data(v)
+        g.add_node_from_data(w)
 
         f = node_exclusion_predicate_builder([u])
 
@@ -351,9 +347,14 @@ class TestNodePredicates(unittest.TestCase):
 
     def test_node_inclusion_tuples(self):
         g = BELGraph()
-        u = g.add_node_from_data(protein(name='S100b', namespace='MGI'))
-        v = g.add_node_from_data(abundance(name='nitric oxide', namespace='CHEBI'))
-        w = g.add_node_from_data(abundance(name='cortisol', namespace='CHEBI', identifier='17650'))
+
+        u=protein(name='S100b', namespace='MGI')
+        v=abundance(name='nitric oxide', namespace='CHEBI')
+        w = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+
+        g.add_node_from_data(u)
+        g.add_node_from_data(v)
+        g.add_node_from_data(w)
 
         f = node_inclusion_predicate_builder([u])
 
@@ -377,8 +378,8 @@ class TestNodePredicates(unittest.TestCase):
         g = BELGraph()
         a, b, c = (protein(n(), n()) for _ in range(3))
 
-        g.add_increases(a, b, n(), n())
-        g.add_increases(b, c, n(), n())
+        g.add_increases(a, b, citation=n(), evidence=n())
+        g.add_increases(b, c, citation=n(), evidence=n())
 
         self.assertTrue(is_causal_source(g, a))
         self.assertFalse(is_causal_central(g, a))
@@ -403,10 +404,10 @@ class TestEdgePredicate(unittest.TestCase):
     def test_has_polarity(self):
         g = BELGraph()
         a, b, c = (protein(n(), n()) for _ in range(3))
-        key1 = g.add_increases(a, b, n(), n())
+        key1 = g.add_increases(a, b, citation=n(), evidence=n())
         self.assertTrue(has_polarity(g, a, b, key1))
 
-        key2 = g.add_association(b, c, n(), n())
+        key2 = g.add_association(b, c, citation=n(), evidence=n())
         self.assertFalse(has_polarity(g, b, c, key2))
 
     def test_has_provenance(self):
@@ -416,8 +417,8 @@ class TestEdgePredicate(unittest.TestCase):
         self.assertTrue(has_provenance({CITATION: {}, EVIDENCE: ''}))
 
     def test_has_pubmed(self):
-        self.assertTrue(has_pubmed({CITATION: {CITATION_TYPE: CITATION_TYPE_PUBMED}}))
-        self.assertFalse(has_pubmed({CITATION: {CITATION_TYPE: CITATION_TYPE_ONLINE}}))
+        self.assertTrue(has_pubmed({CITATION: {CITATION_DB: CITATION_TYPE_PUBMED}}))
+        self.assertFalse(has_pubmed({CITATION: {CITATION_DB: CITATION_TYPE_ONLINE}}))
         self.assertFalse(has_pubmed({}))
 
     def test_has_authors(self):
