@@ -45,7 +45,7 @@ class TestSummary(unittest.TestCase):
         """Test getting and counting namespaces' contents on the sialic acid graph."""
         result = {
             'HGNC': 7,
-            'CHEBI': 1
+            'CHEBI': 1,
         }
 
         self.assertEqual(set(result), get_namespaces(sialic_acid_graph))
@@ -55,7 +55,7 @@ class TestSummary(unittest.TestCase):
         """Test getting and counting namespaces' contents on the EGF graph."""
         result = {
             'HGNC': 10,
-            'GOBP': 1,
+            'GO': 1,
         }
 
         self.assertEqual(set(result), get_namespaces(egf_graph))
@@ -80,14 +80,14 @@ class TestSummary(unittest.TestCase):
         graph = BELGraph()
         graph.namespace_url['HGNC'] = 'http://dummy'
 
-        n = protein_fusion(
+        node = protein_fusion(
             partner_5p=protein(name='A', namespace='HGNC'),
             range_5p=fusion_range('p', 1, 15),
             partner_3p=protein(name='B', namespace='HGNC'),
             range_3p=fusion_range('p', 1, 100)
         )
 
-        graph.add_node_from_data(n)
+        graph.add_node_from_data(node)
 
         result = {
             'A': 1,
@@ -115,11 +115,12 @@ class TestSummary(unittest.TestCase):
     def test_count_pathologies(self):
         """Test counting pathologies in the graph."""
         graph = BELGraph()
-        a, b, c, d = protein(n(), n()), protein(n(), n()), pathology(n(), n()), pathology(n(), n())
+        a, b = (protein(namespace='HGNC', name=n()) for _ in range(2))
+        c, d = (pathology(namespace='DOID', name=n()) for _ in range(2))
 
-        graph.add_association(a, c, n(), n())
-        graph.add_association(a, d, n(), n())
-        graph.add_association(b, d, n(), n())
+        graph.add_association(a, c, citation=n(), evidence=n())
+        graph.add_association(a, d, citation=n(), evidence=n())
+        graph.add_association(b, d, citation=n(), evidence=n())
 
         pathology_counter = count_pathologies(graph)
         self.assertIn(c, pathology_counter)
@@ -127,7 +128,7 @@ class TestSummary(unittest.TestCase):
         self.assertEqual(1, pathology_counter[c])
         self.assertEqual(2, pathology_counter[d])
 
-        top_pathology_counter = get_top_pathologies(graph, count=1)
+        top_pathology_counter = get_top_pathologies(graph, n=1)
         self.assertEqual(1, len(top_pathology_counter))
         node, count = top_pathology_counter[0]
         self.assertEqual(d, node)
@@ -138,11 +139,11 @@ class TestSummary(unittest.TestCase):
         graph = BELGraph()
         a, b, c = protein(n(), n()), protein(n(), n()), pathology(n(), n())
 
-        graph.add_association(a, b, n(), n())
-        graph.add_association(a, c, n(), n())
+        graph.add_association(a, b, citation=n(), evidence=n())
+        graph.add_association(a, c, citation=n(), evidence=n())
 
-        top_hubs = get_top_hubs(graph, count=1)
+        top_hubs = get_top_hubs(graph, n=1)
         self.assertEqual(1, len(top_hubs))
         node, degree = top_hubs[0]
         self.assertEqual(a, node)
-        self.assertEqual(2, degree)
+        self.assertEqual(4, degree)  # higher than expected because association edges
